from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional, Union
from .access_date import (
    ConfAcronym,
    ConfDate,
    ConfLoc,
    ConfName,
    ConfSponsor,
    X,
)
from .conf_num import ConfNum
from .conf_theme import ConfTheme
from .org.w3.pkg_1999.xlink.actuate_value import ActuateValue
from .org.w3.pkg_1999.xlink.show_value import ShowValue
from .org.w3.pkg_1999.xlink.type_value import TypeValue
from .org.w3.xml.pkg_1998.namespace.lang_value import LangValue
from .string_conf import StringConf


@dataclass
class Conference:
    """
    <div> <h3>Conference Information</h3> </div>
    """
    class Meta:
        name = "conference"

    conf_date: List[ConfDate] = field(
        default_factory=list,
        metadata={
            "name": "conf-date",
            "type": "Element",
        }
    )
    conf_name: List[ConfName] = field(
        default_factory=list,
        metadata={
            "name": "conf-name",
            "type": "Element",
        }
    )
    conf_num: List[ConfNum] = field(
        default_factory=list,
        metadata={
            "name": "conf-num",
            "type": "Element",
        }
    )
    conf_loc: List[ConfLoc] = field(
        default_factory=list,
        metadata={
            "name": "conf-loc",
            "type": "Element",
        }
    )
    conf_sponsor: List[ConfSponsor] = field(
        default_factory=list,
        metadata={
            "name": "conf-sponsor",
            "type": "Element",
        }
    )
    conf_theme: List[ConfTheme] = field(
        default_factory=list,
        metadata={
            "name": "conf-theme",
            "type": "Element",
        }
    )
    conf_acronym: List[ConfAcronym] = field(
        default_factory=list,
        metadata={
            "name": "conf-acronym",
            "type": "Element",
        }
    )
    string_conf: List[StringConf] = field(
        default_factory=list,
        metadata={
            "name": "string-conf",
            "type": "Element",
        }
    )
    x: List[X] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    content_type: Optional[str] = field(
        default=None,
        metadata={
            "name": "content-type",
            "type": "Attribute",
        }
    )
    hreflang: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    specific_use: Optional[str] = field(
        default=None,
        metadata={
            "name": "specific-use",
            "type": "Attribute",
        }
    )
    actuate: Optional[ActuateValue] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    role: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    show: Optional[ShowValue] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    title: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    type: TypeValue = field(
        init=False,
        default=TypeValue.SIMPLE,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )
    lang: Optional[Union[str, LangValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )



from enum import Enum


class PubMedPubDatePubStatus(Enum):
    RECEIVED = "received"
    ACCEPTED = "accepted"
    EPUBLISH = "epublish"
    PPUBLISH = "ppublish"
    REVISED = "revised"
    AHEADOFPRINT = "aheadofprint"
    RETRACTED = "retracted"
    ECOLLECTION = "ecollection"
    PMC = "pmc"
    PMCR = "pmcr"
    PUBMED = "pubmed"
    PUBMEDR = "pubmedr"
    PREMEDLINE = "premedline"
    MEDLINE = "medline"
    MEDLINER = "medliner"
    ENTREZ = "entrez"
    PMC_RELEASE = "pmc-release"



from enum import Enum


class OtherAbstractType(Enum):
    AAMC = "AAMC"
    AIDS = "AIDS"
    KIE = "KIE"
    PIP = "PIP"
    NASA = "NASA"
    PUBLISHER = "Publisher"
    PLAIN_LANGUAGE_SUMMARY = "plain-language-summary"



from enum import Enum

__NAMESPACE__ = "http://www.w3.org/1998/Math/MathML"


class MstyleLongdivstyle(Enum):
    LEFTTOP = "lefttop"
    STACKEDRIGHTRIGHT = "stackedrightright"
    MEDIUMSTACKEDRIGHTRIGHT = "mediumstackedrightright"
    SHORTSTACKEDRIGHTRIGHT = "shortstackedrightright"
    RIGHTTOP = "righttop"
    LEFT_RIGHT = "left/\right"
    LEFT_RIGHT_1 = "left)(right"
    RIGHT_RIGHT = ":right=right"
    STACKEDLEFTLEFT = "stackedleftleft"
    STACKEDLEFTLINETOP = "stackedleftlinetop"



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List
from .pmid import Pmid


@dataclass
class DeleteDocument:
    pmid: List[Pmid] = field(
        default_factory=list,
        metadata={
            "name": "PMID",
            "type": "Element",
        }
    )



from enum import Enum


class AbstractTextNlmCategory(Enum):
    BACKGROUND = "BACKGROUND"
    OBJECTIVE = "OBJECTIVE"
    METHODS = "METHODS"
    RESULTS = "RESULTS"
    CONCLUSIONS = "CONCLUSIONS"
    UNASSIGNED = "UNASSIGNED"



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional


@dataclass
class Grant:
    grant_id: Optional[str] = field(
        default=None,
        metadata={
            "name": "GrantID",
            "type": "Element",
        }
    )
    acronym: Optional[str] = field(
        default=None,
        metadata={
            "name": "Acronym",
            "type": "Element",
        }
    )
    agency: Optional[str] = field(
        default=None,
        metadata={
            "name": "Agency",
            "type": "Element",
            "required": True,
        }
    )
    country: Optional[str] = field(
        default=None,
        metadata={
            "name": "Country",
            "type": "Element",
            "required": True,
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional
from .book_document import BookDocument
from .pubmed_book_data import PubmedBookData


@dataclass
class PubmedBookArticle:
    book_document: Optional[BookDocument] = field(
        default=None,
        metadata={
            "name": "BookDocument",
            "type": "Element",
            "required": True,
        }
    )
    pubmed_book_data: Optional[PubmedBookData] = field(
        default=None,
        metadata={
            "name": "PubmedBookData",
            "type": "Element",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .access_date import (
    Ack,
    Bio,
    FnGroup,
    Glossary,
    Label,
    Notes,
    RefList,
    Sec,
    Title,
)
from .app_group import AppGroup


@dataclass
class Back:
    """
    <div> <h3>Back Matter</h3> </div>
    """
    class Meta:
        name = "back"

    label: Optional[Label] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    title: List[Title] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ack: List[Ack] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    app_group: List[AppGroup] = field(
        default_factory=list,
        metadata={
            "name": "app-group",
            "type": "Element",
        }
    )
    bio: List[Bio] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    fn_group: List[FnGroup] = field(
        default_factory=list,
        metadata={
            "name": "fn-group",
            "type": "Element",
        }
    )
    glossary: List[Glossary] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ref_list: List[RefList] = field(
        default_factory=list,
        metadata={
            "name": "ref-list",
            "type": "Element",
        }
    )
    notes: List[Notes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sec: List[Sec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .access_date import (
    AltTitle,
    ArticleTitle,
    FnGroup,
    Subtitle,
)
from .trans_title_group import TransTitleGroup


@dataclass
class TitleGroup:
    """
    <div> <h3>Title Group</h3> </div>
    """
    class Meta:
        name = "title-group"

    article_title: Optional[ArticleTitle] = field(
        default=None,
        metadata={
            "name": "article-title",
            "type": "Element",
            "required": True,
        }
    )
    subtitle: List[Subtitle] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    trans_title_group: List[TransTitleGroup] = field(
        default_factory=list,
        metadata={
            "name": "trans-title-group",
            "type": "Element",
        }
    )
    alt_title: List[AltTitle] = field(
        default_factory=list,
        metadata={
            "name": "alt-title",
            "type": "Element",
        }
    )
    fn_group: Optional[FnGroup] = field(
        default=None,
        metadata={
            "name": "fn-group",
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )



from enum import Enum


class MedlineCitationStatus(Enum):
    COMPLETED = "Completed"
    IN_PROCESS = "In-Process"
    PUB_MED_NOT_MEDLINE = "PubMed-not-MEDLINE"
    IN_DATA_REVIEW = "In-Data-Review"
    PUBLISHER = "Publisher"
    MEDLINE = "MEDLINE"
    OLDMEDLINE = "OLDMEDLINE"



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Dict, List, Optional, Union
from .columnalignstyle import Columnalignstyle
from .linestyle import Linestyle
from .mlabeledtr import Mlabeledtr
from .mtable_displaystyle import MtableDisplaystyle
from .mtable_equalcolumns import MtableEqualcolumns
from .mtable_equalrows import MtableEqualrows
from .mtable_side import MtableSide
from .mtable_value import MtableValue
from .mtr import Mtr
from .verticalalign import Verticalalign

__NAMESPACE__ = "http://www.w3.org/1998/Math/MathML"


@dataclass
class Mtable:
    class Meta:
        name = "mtable"
        namespace = "http://www.w3.org/1998/Math/MathML"

    mtr: List[Mtr] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mlabeledtr: List[Mlabeledtr] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    mathcolor: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    mathbackground: Optional[Union[str, MtableValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    align: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*(top|bottom|center|baseline|axis)\s*[0-9]*",
        }
    )
    rowalign: List[Verticalalign] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "tokens": True,
        }
    )
    columnalign: List[Columnalignstyle] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "tokens": True,
        }
    )
    groupalign: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"(\s*\{\s*(left|center|right|decimalpoint)(\s+(left|center|right|decimalpoint))*\})*\s*",
        }
    )
    alignmentscope: List[MtableValue] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "tokens": True,
        }
    )
    columnwidth: List[MtableValue] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "tokens": True,
        }
    )
    width: Optional[Union[str, MtableValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    rowspacing: List[str] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
            "tokens": True,
        }
    )
    columnspacing: List[str] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
            "tokens": True,
        }
    )
    rowlines: List[Linestyle] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "tokens": True,
        }
    )
    columnlines: List[Linestyle] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "tokens": True,
        }
    )
    frame: Optional[Linestyle] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    framespacing: List[object] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "length": 2,
            "tokens": True,
        }
    )
    equalrows: Optional[MtableEqualrows] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    equalcolumns: Optional[MtableEqualcolumns] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    displaystyle: Optional[MtableDisplaystyle] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    side: Optional[MtableSide] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    minlabelspacing: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )



from enum import Enum

__NAMESPACE__ = "http://www.w3.org/1998/Math/MathML"


class MoIndentalignfirst(Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"
    AUTO = "auto"
    ID = "id"
    INDENTALIGN = "indentalign"



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .article_1 import Article1
from .chemical_list import ChemicalList
from .coi_statement import CoiStatement
from .comments_corrections_list import CommentsCorrectionsList
from .date_completed import DateCompleted
from .date_revised import DateRevised
from .gene_symbol_list import GeneSymbolList
from .general_note import GeneralNote
from .investigator_list import InvestigatorList
from .keyword_list import KeywordList
from .medline_citation_owner import MedlineCitationOwner
from .medline_citation_status import MedlineCitationStatus
from .medline_journal_info import MedlineJournalInfo
from .mesh_heading_list import MeshHeadingList
from .other_abstract import OtherAbstract
from .other_id import OtherId
from .personal_name_subject_list import PersonalNameSubjectList
from .pmid import Pmid
from .suppl_mesh_list import SupplMeshList


@dataclass
class MedlineCitation:
    owner: MedlineCitationOwner = field(
        default=MedlineCitationOwner.NLM,
        metadata={
            "name": "Owner",
            "type": "Attribute",
            "required": True,
        }
    )
    indexing_method: Optional[str] = field(
        default=None,
        metadata={
            "name": "IndexingMethod",
            "type": "Attribute",
        }
    )
    version_date: Optional[str] = field(
        default=None,
        metadata={
            "name": "VersionDate",
            "type": "Attribute",
        }
    )
    version_id: Optional[str] = field(
        default=None,
        metadata={
            "name": "VersionID",
            "type": "Attribute",
        }
    )
    status: Optional[MedlineCitationStatus] = field(
        default=None,
        metadata={
            "name": "Status",
            "type": "Attribute",
            "required": True,
        }
    )
    pmid: Optional[Pmid] = field(
        default=None,
        metadata={
            "name": "PMID",
            "type": "Element",
            "required": True,
        }
    )
    date_completed: Optional[DateCompleted] = field(
        default=None,
        metadata={
            "name": "DateCompleted",
            "type": "Element",
        }
    )
    date_revised: Optional[DateRevised] = field(
        default=None,
        metadata={
            "name": "DateRevised",
            "type": "Element",
        }
    )
    article: Optional[Article1] = field(
        default=None,
        metadata={
            "name": "Article",
            "type": "Element",
            "required": True,
        }
    )
    medline_journal_info: Optional[MedlineJournalInfo] = field(
        default=None,
        metadata={
            "name": "MedlineJournalInfo",
            "type": "Element",
            "required": True,
        }
    )
    chemical_list: Optional[ChemicalList] = field(
        default=None,
        metadata={
            "name": "ChemicalList",
            "type": "Element",
        }
    )
    suppl_mesh_list: Optional[SupplMeshList] = field(
        default=None,
        metadata={
            "name": "SupplMeshList",
            "type": "Element",
        }
    )
    citation_subset: List[str] = field(
        default_factory=list,
        metadata={
            "name": "CitationSubset",
            "type": "Element",
        }
    )
    comments_corrections_list: Optional[CommentsCorrectionsList] = field(
        default=None,
        metadata={
            "name": "CommentsCorrectionsList",
            "type": "Element",
        }
    )
    gene_symbol_list: Optional[GeneSymbolList] = field(
        default=None,
        metadata={
            "name": "GeneSymbolList",
            "type": "Element",
        }
    )
    mesh_heading_list: Optional[MeshHeadingList] = field(
        default=None,
        metadata={
            "name": "MeshHeadingList",
            "type": "Element",
        }
    )
    number_of_references: Optional[str] = field(
        default=None,
        metadata={
            "name": "NumberOfReferences",
            "type": "Element",
        }
    )
    personal_name_subject_list: Optional[PersonalNameSubjectList] = field(
        default=None,
        metadata={
            "name": "PersonalNameSubjectList",
            "type": "Element",
        }
    )
    other_id: List[OtherId] = field(
        default_factory=list,
        metadata={
            "name": "OtherID",
            "type": "Element",
        }
    )
    other_abstract: List[OtherAbstract] = field(
        default_factory=list,
        metadata={
            "name": "OtherAbstract",
            "type": "Element",
        }
    )
    keyword_list: List[KeywordList] = field(
        default_factory=list,
        metadata={
            "name": "KeywordList",
            "type": "Element",
        }
    )
    coi_statement: Optional[CoiStatement] = field(
        default=None,
        metadata={
            "name": "CoiStatement",
            "type": "Element",
        }
    )
    space_flight_mission: List[str] = field(
        default_factory=list,
        metadata={
            "name": "SpaceFlightMission",
            "type": "Element",
        }
    )
    investigator_list: Optional[InvestigatorList] = field(
        default=None,
        metadata={
            "name": "InvestigatorList",
            "type": "Element",
        }
    )
    general_note: List[GeneralNote] = field(
        default_factory=list,
        metadata={
            "name": "GeneralNote",
            "type": "Element",
        }
    )



from enum import Enum

__NAMESPACE__ = "http://www.w3.org/1998/Math/MathML"


class MstyleLocation(Enum):
    W = "w"
    NW = "nw"
    N = "n"
    NE = "ne"
    E = "e"
    SE = "se"
    S = "s"
    SW = "sw"



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional
from .other_id_source import OtherIdSource


@dataclass
class OtherId:
    class Meta:
        name = "OtherID"

    source: Optional[OtherIdSource] = field(
        default=None,
        metadata={
            "name": "Source",
            "type": "Attribute",
            "required": True,
        }
    )
    value: str = field(
        default="",
        metadata={
            "required": True,
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional


@dataclass
class EndingDate:
    year: Optional[str] = field(
        default=None,
        metadata={
            "name": "Year",
            "type": "Element",
            "required": True,
        }
    )
    month: Optional[str] = field(
        default=None,
        metadata={
            "name": "Month",
            "type": "Element",
        }
    )
    day: Optional[str] = field(
        default=None,
        metadata={
            "name": "Day",
            "type": "Element",
        }
    )
    season: Optional[str] = field(
        default=None,
        metadata={
            "name": "Season",
            "type": "Element",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List
from .keyword import Keyword
from .keyword_list_owner import KeywordListOwner


@dataclass
class KeywordList:
    owner: KeywordListOwner = field(
        default=KeywordListOwner.NLM,
        metadata={
            "name": "Owner",
            "type": "Attribute",
            "required": True,
        }
    )
    keyword: List[Keyword] = field(
        default_factory=list,
        metadata={
            "name": "Keyword",
            "type": "Element",
            "min_occurs": 1,
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List
from .access_date import (
    Sub,
    Sup,
)
from .u import (
    B,
    I,
    U,
)


@dataclass
class Sup1:
    class Meta:
        name = "sup"

    content: List[object] = field(
        default_factory=list,
        metadata={
            "type": "Wildcard",
            "namespace": "##any",
            "mixed": True,
            "choices": (
                {
                    "name": "b",
                    "type": B,
                },
                {
                    "name": "i",
                    "type": I,
                },
                {
                    "name": "sup",
                    "type": Sup,
                },
                {
                    "name": "sub",
                    "type": Sub,
                },
                {
                    "name": "u",
                    "type": U,
                },
            ),
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Dict, List, Optional, Union
from .mspace_dir import MspaceDir
from .mspace_fontstyle import MspaceFontstyle
from .mspace_fontweight import MspaceFontweight
from .mspace_linebreak import MspaceLinebreak
from .mspace_mathvariant import MspaceMathvariant
from .mspace_value import MspaceValue

__NAMESPACE__ = "http://www.w3.org/1998/Math/MathML"


@dataclass
class Mspace:
    class Meta:
        name = "mspace"
        namespace = "http://www.w3.org/1998/Math/MathML"

    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    mathcolor: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    mathbackground: Optional[Union[str, MspaceValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    mathvariant: Optional[MspaceMathvariant] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    mathsize: Optional[Union[str, MspaceValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    dir: Optional[MspaceDir] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    fontfamily: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    fontweight: Optional[MspaceFontweight] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    fontstyle: Optional[MspaceFontstyle] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    fontsize: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    color: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    background: Optional[Union[str, MspaceValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    width: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    height: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    depth: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    linebreak: Optional[MspaceLinebreak] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from .first_name_empty_yn import FirstNameEmptyYn


@dataclass
class FirstName:
    empty_yn: FirstNameEmptyYn = field(
        default=FirstNameEmptyYn.N,
        metadata={
            "name": "EmptyYN",
            "type": "Attribute",
            "required": True,
        }
    )
    value: str = field(
        default="",
        metadata={
            "required": True,
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .access_date import (
    Abstract2,
    Aff,
    AffAlternatives,
    ContribGroup,
    Email,
    ExtLink,
    Isbn,
    Issue,
    IssuePart,
    IssueTitle,
    KwdGroup,
    Permissions,
    Product,
    RelatedArticle,
    RelatedObject,
    Supplement,
    SupplementaryMaterial,
    Uri,
    Volume,
    VolumeId,
    VolumeSeries,
    X,
)
from .article_categories import ArticleCategories
from .article_id import ArticleId
from .article_version import ArticleVersion
from .article_version_alternatives import ArticleVersionAlternatives
from .author_notes import AuthorNotes
from .conference import Conference
from .counts import Counts
from .custom_meta_group import CustomMetaGroup
from .elocation_id import ElocationId
from .fpage import Fpage
from .funding_group import FundingGroup
from .history_2 import History2
from .issue_id import IssueId
from .issue_sponsor import IssueSponsor
from .issue_title_group import IssueTitleGroup
from .lpage import Lpage
from .page_range import PageRange
from .pub_date_2 import PubDate2
from .pub_date_not_available import PubDateNotAvailable
from .pub_history import PubHistory
from .self_uri import SelfUri
from .support_group import SupportGroup
from .title_group import TitleGroup
from .trans_abstract import TransAbstract
from .volume_issue_group import VolumeIssueGroup


@dataclass
class FrontStub:
    """
    <div> <h3>Stub Front Metadata</h3> </div>
    """
    class Meta:
        name = "front-stub"

    article_id: List[ArticleId] = field(
        default_factory=list,
        metadata={
            "name": "article-id",
            "type": "Element",
        }
    )
    article_version: Optional[ArticleVersion] = field(
        default=None,
        metadata={
            "name": "article-version",
            "type": "Element",
        }
    )
    article_version_alternatives: Optional[ArticleVersionAlternatives] = field(
        default=None,
        metadata={
            "name": "article-version-alternatives",
            "type": "Element",
        }
    )
    article_categories: Optional[ArticleCategories] = field(
        default=None,
        metadata={
            "name": "article-categories",
            "type": "Element",
        }
    )
    title_group: Optional[TitleGroup] = field(
        default=None,
        metadata={
            "name": "title-group",
            "type": "Element",
        }
    )
    contrib_group: List[ContribGroup] = field(
        default_factory=list,
        metadata={
            "name": "contrib-group",
            "type": "Element",
        }
    )
    aff: List[Aff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    aff_alternatives: List[AffAlternatives] = field(
        default_factory=list,
        metadata={
            "name": "aff-alternatives",
            "type": "Element",
        }
    )
    x: List[X] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    author_notes: Optional[AuthorNotes] = field(
        default=None,
        metadata={
            "name": "author-notes",
            "type": "Element",
        }
    )
    pub_date: List[PubDate2] = field(
        default_factory=list,
        metadata={
            "name": "pub-date",
            "type": "Element",
        }
    )
    pub_date_not_available: Optional[PubDateNotAvailable] = field(
        default=None,
        metadata={
            "name": "pub-date-not-available",
            "type": "Element",
        }
    )
    volume: List[Volume] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    volume_id: List[VolumeId] = field(
        default_factory=list,
        metadata={
            "name": "volume-id",
            "type": "Element",
        }
    )
    volume_series: Optional[VolumeSeries] = field(
        default=None,
        metadata={
            "name": "volume-series",
            "type": "Element",
        }
    )
    issue: List[Issue] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    issue_id: List[IssueId] = field(
        default_factory=list,
        metadata={
            "name": "issue-id",
            "type": "Element",
        }
    )
    issue_title: List[IssueTitle] = field(
        default_factory=list,
        metadata={
            "name": "issue-title",
            "type": "Element",
        }
    )
    issue_title_group: List[IssueTitleGroup] = field(
        default_factory=list,
        metadata={
            "name": "issue-title-group",
            "type": "Element",
        }
    )
    issue_sponsor: List[IssueSponsor] = field(
        default_factory=list,
        metadata={
            "name": "issue-sponsor",
            "type": "Element",
        }
    )
    issue_part: Optional[IssuePart] = field(
        default=None,
        metadata={
            "name": "issue-part",
            "type": "Element",
        }
    )
    volume_issue_group: List[VolumeIssueGroup] = field(
        default_factory=list,
        metadata={
            "name": "volume-issue-group",
            "type": "Element",
        }
    )
    isbn: List[Isbn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    supplement: Optional[Supplement] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    fpage: Optional[Fpage] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    lpage: Optional[Lpage] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    page_range: Optional[PageRange] = field(
        default=None,
        metadata={
            "name": "page-range",
            "type": "Element",
        }
    )
    elocation_id: Optional[ElocationId] = field(
        default=None,
        metadata={
            "name": "elocation-id",
            "type": "Element",
        }
    )
    email: List[Email] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ext_link: List[ExtLink] = field(
        default_factory=list,
        metadata={
            "name": "ext-link",
            "type": "Element",
        }
    )
    uri: List[Uri] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    product: List[Product] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    supplementary_material: List[SupplementaryMaterial] = field(
        default_factory=list,
        metadata={
            "name": "supplementary-material",
            "type": "Element",
        }
    )
    history: Optional[History2] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    pub_history: Optional[PubHistory] = field(
        default=None,
        metadata={
            "name": "pub-history",
            "type": "Element",
        }
    )
    permissions: Optional[Permissions] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    self_uri: List[SelfUri] = field(
        default_factory=list,
        metadata={
            "name": "self-uri",
            "type": "Element",
        }
    )
    related_article: List[RelatedArticle] = field(
        default_factory=list,
        metadata={
            "name": "related-article",
            "type": "Element",
        }
    )
    related_object: List[RelatedObject] = field(
        default_factory=list,
        metadata={
            "name": "related-object",
            "type": "Element",
        }
    )
    abstract: List[Abstract2] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    trans_abstract: List[TransAbstract] = field(
        default_factory=list,
        metadata={
            "name": "trans-abstract",
            "type": "Element",
        }
    )
    kwd_group: List[KwdGroup] = field(
        default_factory=list,
        metadata={
            "name": "kwd-group",
            "type": "Element",
        }
    )
    funding_group: List[FundingGroup] = field(
        default_factory=list,
        metadata={
            "name": "funding-group",
            "type": "Element",
        }
    )
    support_group: List[SupportGroup] = field(
        default_factory=list,
        metadata={
            "name": "support-group",
            "type": "Element",
        }
    )
    conference: List[Conference] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    counts: Optional[Counts] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    custom_meta_group: Optional[CustomMetaGroup] = field(
        default=None,
        metadata={
            "name": "custom-meta-group",
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional, Union
from .back import Back
from .body import Body
from .floats_group import FloatsGroup
from .front import Front
from .front_stub import FrontStub
from .org.w3.xml.pkg_1998.namespace.lang_value import LangValue
from .processing_meta import ProcessingMeta


@dataclass
class Response:
    """
    <div> <h3>Response</h3> </div>
    """
    class Meta:
        name = "response"

    processing_meta: Optional[ProcessingMeta] = field(
        default=None,
        metadata={
            "name": "processing-meta",
            "type": "Element",
        }
    )
    front: Optional[Front] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    front_stub: Optional[FrontStub] = field(
        default=None,
        metadata={
            "name": "front-stub",
            "type": "Element",
        }
    )
    body: Optional[Body] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    back: Optional[Back] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    floats_group: Optional[FloatsGroup] = field(
        default=None,
        metadata={
            "name": "floats-group",
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    response_type: Optional[str] = field(
        default=None,
        metadata={
            "name": "response-type",
            "type": "Attribute",
        }
    )
    specific_use: Optional[str] = field(
        default=None,
        metadata={
            "name": "specific-use",
            "type": "Attribute",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )
    lang: Optional[Union[str, LangValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .affiliation_info import AffiliationInfo
from .first_name import FirstName
from .identifier import Identifier


@dataclass
class IndividualName:
    first_name: Optional[FirstName] = field(
        default=None,
        metadata={
            "name": "FirstName",
            "type": "Element",
            "required": True,
        }
    )
    middle_name: Optional[str] = field(
        default=None,
        metadata={
            "name": "MiddleName",
            "type": "Element",
        }
    )
    last_name: Optional[str] = field(
        default=None,
        metadata={
            "name": "LastName",
            "type": "Element",
            "required": True,
        }
    )
    suffix: Optional[str] = field(
        default=None,
        metadata={
            "name": "Suffix",
            "type": "Element",
        }
    )
    affiliation: Optional[str] = field(
        default=None,
        metadata={
            "name": "Affiliation",
            "type": "Element",
        }
    )
    affiliation_info: Optional[AffiliationInfo] = field(
        default=None,
        metadata={
            "name": "AffiliationInfo",
            "type": "Element",
        }
    )
    identifier: List[Identifier] = field(
        default_factory=list,
        metadata={
            "name": "Identifier",
            "type": "Element",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional
from .suffix_1 import Suffix1


@dataclass
class PersonalNameSubject:
    last_name: Optional[str] = field(
        default=None,
        metadata={
            "name": "LastName",
            "type": "Element",
            "required": True,
        }
    )
    fore_name: Optional[str] = field(
        default=None,
        metadata={
            "name": "ForeName",
            "type": "Element",
        }
    )
    initials: Optional[str] = field(
        default=None,
        metadata={
            "name": "Initials",
            "type": "Element",
        }
    )
    suffix: Optional[Suffix1] = field(
        default=None,
        metadata={
            "name": "Suffix",
            "type": "Element",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .param import Param


@dataclass
class Object:
    type: Optional[str] = field(
        default=None,
        metadata={
            "name": "Type",
            "type": "Attribute",
            "required": True,
        }
    )
    param: List[Param] = field(
        default_factory=list,
        metadata={
            "name": "Param",
            "type": "Element",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .individual_name import IndividualName


@dataclass
class Group:
    group_name: Optional[str] = field(
        default=None,
        metadata={
            "name": "GroupName",
            "type": "Element",
        }
    )
    individual_name: List[IndividualName] = field(
        default_factory=list,
        metadata={
            "name": "IndividualName",
            "type": "Element",
            "min_occurs": 1,
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .resource_id import ResourceId
from .resource_name import ResourceName


@dataclass
class ResourceWrap:
    """
    <div> <h3>Resource Wrap</h3> </div>
    """
    class Meta:
        name = "resource-wrap"

    resource_name: Optional[ResourceName] = field(
        default=None,
        metadata={
            "name": "resource-name",
            "type": "Element",
            "required": True,
        }
    )
    resource_id: List[ResourceId] = field(
        default_factory=list,
        metadata={
            "name": "resource-id",
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional
from .elocation_id_eid_type import ElocationIdEidType
from .elocation_id_valid_yn import ElocationIdValidYn


@dataclass
class ElocationId1:
    class Meta:
        name = "ELocationID"

    eid_type: Optional[ElocationIdEidType] = field(
        default=None,
        metadata={
            "name": "EIdType",
            "type": "Attribute",
            "required": True,
        }
    )
    valid_yn: ElocationIdValidYn = field(
        default=ElocationIdValidYn.Y,
        metadata={
            "name": "ValidYN",
            "type": "Attribute",
            "required": True,
        }
    )
    value: str = field(
        default="",
        metadata={
            "required": True,
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional

__NAMESPACE__ = "http://www.w3.org/1998/Math/MathML"


@dataclass
class Selector:
    class Meta:
        name = "selector"
        namespace = "http://www.w3.org/1998/Math/MathML"

    any_element: Optional[object] = field(
        default=None,
        metadata={
            "type": "Wildcard",
            "namespace": "##any",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional


@dataclass
class MedlineJournalInfo:
    country: Optional[str] = field(
        default=None,
        metadata={
            "name": "Country",
            "type": "Element",
        }
    )
    medline_ta: Optional[str] = field(
        default=None,
        metadata={
            "name": "MedlineTA",
            "type": "Element",
            "required": True,
        }
    )
    nlm_unique_id: Optional[str] = field(
        default=None,
        metadata={
            "name": "NlmUniqueID",
            "type": "Element",
        }
    )
    issnlinking: Optional[str] = field(
        default=None,
        metadata={
            "name": "ISSNLinking",
            "type": "Element",
        }
    )



from .abs import Abs
from .and_mod import And
from .annotation import Annotation
from .approx import Approx
from .arccos import Arccos
from .arccosh import Arccosh
from .arccot import Arccot
from .arccoth import Arccoth
from .arccsc import Arccsc
from .arccsch import Arccsch
from .arcsec import Arcsec
from .arcsech import Arcsech
from .arcsin import Arcsin
from .arcsinh import Arcsinh
from .arctan import Arctan
from .arctanh import Arctanh
from .arg import Arg
from .card import Card
from .cartesianproduct import Cartesianproduct
from .cbytes import Cbytes
from .ceiling import Ceiling
from .codomain import Codomain
from .columnalignstyle import Columnalignstyle
from .complexes import Complexes
from .compose import Compose
from .condition import (
    ImpliedMrow,
    AnnotationXml,
    AnnotationXmlModel,
    Apply,
    ApplyContent,
    Bind,
    BindContent,
    Bvar,
    Cerror,
    Ci,
    CiContent,
    Cn,
    CnContent,
    Condition,
    Csymbol,
    CsymbolContent,
    Declare,
    Degree,
    Domainofapplication,
    Fn,
    ListType,
    Logbase,
    Lowlimit,
    Maction,
    Menclose,
    Merror,
    Mfenced,
    Mfrac,
    Mlongdiv,
    Mmultiscripts,
    Momentabout,
    Mover,
    Mpadded,
    Mphantom,
    Mroot,
    Mrow,
    Mscarries,
    Mscarry,
    Msgroup,
    Msqrt,
    Msrow,
    Mstack,
    Mstyle,
    Msub,
    Msubsup,
    Msup,
    Munder,
    Munderover,
    Otherwise,
    Piece,
    Piecewise,
    Reln,
    Set,
    Uplimit,
)
from .conjugate import Conjugate
from .cos import Cos
from .cosh import Cosh
from .cot import Cot
from .coth import Coth
from .cs import Cs
from .csc import Csc
from .csch import Csch
from .curl import Curl
from .declare_occurrence import DeclareOccurrence
from .determinant import Determinant
from .diff import Diff
from .divergence import Divergence
from .divide import Divide
from .domain import Domain
from .emptyset import Emptyset
from .eq import Eq
from .equivalent import Equivalent
from .eulergamma import Eulergamma
from .exists import Exists
from .exp import Exp
from .exponentiale import Exponentiale
from .factorial import Factorial
from .factorof import Factorof
from .false import FalseType
from .floor import Floor
from .forall import Forall
from .gcd import Gcd
from .geq import Geq
from .grad import Grad
from .gt import Gt
from .ident import Ident
from .image import Image
from .imaginary import Imaginary
from .imaginaryi import Imaginaryi
from .implies import Implies
from .in_mod import In
from .infinity import Infinity
from .int_mod import Int
from .integers import Integers
from .intersect import Intersect
from .interval import Interval
from .inverse import Inverse
from .lambda_mod import Lambda
from .laplacian import Laplacian
from .lcm import Lcm
from .leq import Leq
from .limit import Limit
from .linestyle import Linestyle
from .list_order import ListOrder
from .ln import Ln
from .log import Log
from .lt import Lt
from .maction_value import MactionValue
from .maligngroup import Maligngroup
from .maligngroup_groupalign import MaligngroupGroupalign
from .maligngroup_value import MaligngroupValue
from .malignmark import Malignmark
from .malignmark_edge import MalignmarkEdge
from .malignmark_value import MalignmarkValue
from .math import Math
from .math_accent import MathAccent
from .math_accentunder import MathAccentunder
from .math_align import MathAlign
from .math_bevelled import MathBevelled
from .math_charalign import MathCharalign
from .math_denomalign import MathDenomalign
from .math_dir import MathDir
from .math_display import MathDisplay
from .math_displaystyle import MathDisplaystyle
from .math_edge import MathEdge
from .math_equalcolumns import MathEqualcolumns
from .math_equalrows import MathEqualrows
from .math_fence import MathFence
from .math_form import MathForm
from .math_indentalign import MathIndentalign
from .math_indentalignfirst import MathIndentalignfirst
from .math_indentalignlast import MathIndentalignlast
from .math_infixlinebreakstyle import MathInfixlinebreakstyle
from .math_largeop import MathLargeop
from .math_linebreak import MathLinebreak
from .math_linebreakstyle import MathLinebreakstyle
from .math_location import MathLocation
from .math_longdivstyle import MathLongdivstyle
from .math_mathvariant import MathMathvariant
from .math_movablelimits import MathMovablelimits
from .math_numalign import MathNumalign
from .math_overflow import MathOverflow
from .math_separator import MathSeparator
from .math_side import MathSide
from .math_stackalign import MathStackalign
from .math_stretchy import MathStretchy
from .math_symmetric import MathSymmetric
from .math_value import MathValue
from .matrix import Matrix
from .matrixrow import Matrixrow
from .max import Max
from .mean import Mean
from .median import Median
from .menclose_value import MencloseValue
from .merror_value import MerrorValue
from .mfenced_value import MfencedValue
from .mfrac_bevelled import MfracBevelled
from .mfrac_denomalign import MfracDenomalign
from .mfrac_numalign import MfracNumalign
from .mfrac_value import MfracValue
from .mglyph import Mglyph
from .mglyph_fontstyle import MglyphFontstyle
from .mglyph_fontweight import MglyphFontweight
from .mglyph_mathvariant import MglyphMathvariant
from .mglyph_value import MglyphValue
from .mi import Mi
from .mi_dir import MiDir
from .mi_fontstyle import MiFontstyle
from .mi_fontweight import MiFontweight
from .mi_mathvariant import MiMathvariant
from .mi_value import MiValue
from .min import Min
from .minus import Minus
from .mlabeledtr import Mlabeledtr
from .mlabeledtr_rowalign import MlabeledtrRowalign
from .mlabeledtr_value import MlabeledtrValue
from .mlongdiv_longdivstyle import MlongdivLongdivstyle
from .mlongdiv_value import MlongdivValue
from .mmultiscripts_value import MmultiscriptsValue
from .mn import Mn
from .mn_dir import MnDir
from .mn_fontstyle import MnFontstyle
from .mn_fontweight import MnFontweight
from .mn_mathvariant import MnMathvariant
from .mn_value import MnValue
from .mo import Mo
from .mo_accent import MoAccent
from .mo_dir import MoDir
from .mo_fence import MoFence
from .mo_fontstyle import MoFontstyle
from .mo_fontweight import MoFontweight
from .mo_form import MoForm
from .mo_indentalign import MoIndentalign
from .mo_indentalignfirst import MoIndentalignfirst
from .mo_indentalignlast import MoIndentalignlast
from .mo_largeop import MoLargeop
from .mo_linebreak import MoLinebreak
from .mo_linebreakstyle import MoLinebreakstyle
from .mo_mathvariant import MoMathvariant
from .mo_movablelimits import MoMovablelimits
from .mo_separator import MoSeparator
from .mo_stretchy import MoStretchy
from .mo_symmetric import MoSymmetric
from .mo_value import MoValue
from .mode import Mode
from .moment import Moment
from .mover_accent import MoverAccent
from .mover_align import MoverAlign
from .mover_value import MoverValue
from .mpadded_value import MpaddedValue
from .mphantom_value import MphantomValue
from .mprescripts import Mprescripts
from .mprescripts_value import MprescriptsValue
from .mroot_value import MrootValue
from .mrow_dir import MrowDir
from .mrow_value import MrowValue
from .ms import Ms
from .ms_dir import MsDir
from .ms_fontstyle import MsFontstyle
from .ms_fontweight import MsFontweight
from .ms_mathvariant import MsMathvariant
from .ms_value import MsValue
from .mscarries_location import MscarriesLocation
from .mscarries_value import MscarriesValue
from .mscarry_location import MscarryLocation
from .mscarry_value import MscarryValue
from .msgroup_value import MsgroupValue
from .msline import Msline
from .msline_value import MslineValue
from .mspace import Mspace
from .mspace_dir import MspaceDir
from .mspace_fontstyle import MspaceFontstyle
from .mspace_fontweight import MspaceFontweight
from .mspace_linebreak import MspaceLinebreak
from .mspace_mathvariant import MspaceMathvariant
from .mspace_value import MspaceValue
from .msqrt_value import MsqrtValue
from .msrow_value import MsrowValue
from .mstack_charalign import MstackCharalign
from .mstack_stackalign import MstackStackalign
from .mstack_value import MstackValue
from .mstyle_accent import MstyleAccent
from .mstyle_accentunder import MstyleAccentunder
from .mstyle_align import MstyleAlign
from .mstyle_bevelled import MstyleBevelled
from .mstyle_charalign import MstyleCharalign
from .mstyle_denomalign import MstyleDenomalign
from .mstyle_dir import MstyleDir
from .mstyle_displaystyle import MstyleDisplaystyle
from .mstyle_edge import MstyleEdge
from .mstyle_equalcolumns import MstyleEqualcolumns
from .mstyle_equalrows import MstyleEqualrows
from .mstyle_fence import MstyleFence
from .mstyle_fontstyle import MstyleFontstyle
from .mstyle_fontweight import MstyleFontweight
from .mstyle_form import MstyleForm
from .mstyle_indentalign import MstyleIndentalign
from .mstyle_indentalignfirst import MstyleIndentalignfirst
from .mstyle_indentalignlast import MstyleIndentalignlast
from .mstyle_infixlinebreakstyle import MstyleInfixlinebreakstyle
from .mstyle_largeop import MstyleLargeop
from .mstyle_linebreak import MstyleLinebreak
from .mstyle_linebreakstyle import MstyleLinebreakstyle
from .mstyle_location import MstyleLocation
from .mstyle_longdivstyle import MstyleLongdivstyle
from .mstyle_mathvariant import MstyleMathvariant
from .mstyle_movablelimits import MstyleMovablelimits
from .mstyle_numalign import MstyleNumalign
from .mstyle_separator import MstyleSeparator
from .mstyle_side import MstyleSide
from .mstyle_stackalign import MstyleStackalign
from .mstyle_stretchy import MstyleStretchy
from .mstyle_symmetric import MstyleSymmetric
from .mstyle_value import MstyleValue
from .msub_value import MsubValue
from .msubsup_value import MsubsupValue
from .msup_value import MsupValue
from .mtable import Mtable
from .mtable_displaystyle import MtableDisplaystyle
from .mtable_equalcolumns import MtableEqualcolumns
from .mtable_equalrows import MtableEqualrows
from .mtable_side import MtableSide
from .mtable_value import MtableValue
from .mtd import Mtd
from .mtext import Mtext
from .mtext_dir import MtextDir
from .mtext_fontstyle import MtextFontstyle
from .mtext_fontweight import MtextFontweight
from .mtext_mathvariant import MtextMathvariant
from .mtext_value import MtextValue
from .mtr import Mtr
from .mtr_rowalign import MtrRowalign
from .mtr_value import MtrValue
from .munder_accentunder import MunderAccentunder
from .munder_align import MunderAlign
from .munder_value import MunderValue
from .munderover_accent import MunderoverAccent
from .munderover_accentunder import MunderoverAccentunder
from .munderover_align import MunderoverAlign
from .munderover_value import MunderoverValue
from .naturalnumbers import Naturalnumbers
from .neq import Neq
from .none import NoneType
from .none_value import NoneValue
from .not_mod import Not
from .notanumber import Notanumber
from .notin import Notin
from .notprsubset import Notprsubset
from .notsubset import Notsubset
from .or_mod import Or
from .outerproduct import Outerproduct
from .partialdiff import Partialdiff
from .pi import Pi
from .plus import Plus
from .power import Power
from .primes import Primes
from .product import Product
from .prsubset import Prsubset
from .quotient import Quotient
from .rationals import Rationals
from .real import Real
from .reals import Reals
from .rem import Rem
from .root import Root
from .scalarproduct import Scalarproduct
from .sdev import Sdev
from .sec import Sec
from .sech import Sech
from .selector import Selector
from .sep import Sep
from .setdiff import Setdiff
from .share import Share
from .sin import Sin
from .sinh import Sinh
from .subset import Subset
from .sum import Sum
from .tan import Tan
from .tanh import Tanh
from .tendsto import Tendsto
from .times import Times
from .transpose import Transpose
from .true import TrueType
from .union import UnionType
from .variance import Variance
from .vector import Vector
from .vectorproduct import Vectorproduct
from .verticalalign import Verticalalign
from .xor import Xor

__all__ = [
    "Abs",
    "And",
    "Annotation",
    "Approx",
    "Arccos",
    "Arccosh",
    "Arccot",
    "Arccoth",
    "Arccsc",
    "Arccsch",
    "Arcsec",
    "Arcsech",
    "Arcsin",
    "Arcsinh",
    "Arctan",
    "Arctanh",
    "Arg",
    "Card",
    "Cartesianproduct",
    "Cbytes",
    "Ceiling",
    "Codomain",
    "Columnalignstyle",
    "Complexes",
    "Compose",
    "ImpliedMrow",
    "AnnotationXml",
    "AnnotationXmlModel",
    "Apply",
    "ApplyContent",
    "Bind",
    "BindContent",
    "Bvar",
    "Cerror",
    "Ci",
    "CiContent",
    "Cn",
    "CnContent",
    "Condition",
    "Csymbol",
    "CsymbolContent",
    "Declare",
    "Degree",
    "Domainofapplication",
    "Fn",
    "ListType",
    "Logbase",
    "Lowlimit",
    "Maction",
    "Menclose",
    "Merror",
    "Mfenced",
    "Mfrac",
    "Mlongdiv",
    "Mmultiscripts",
    "Momentabout",
    "Mover",
    "Mpadded",
    "Mphantom",
    "Mroot",
    "Mrow",
    "Mscarries",
    "Mscarry",
    "Msgroup",
    "Msqrt",
    "Msrow",
    "Mstack",
    "Mstyle",
    "Msub",
    "Msubsup",
    "Msup",
    "Munder",
    "Munderover",
    "Otherwise",
    "Piece",
    "Piecewise",
    "Reln",
    "Set",
    "Uplimit",
    "Conjugate",
    "Cos",
    "Cosh",
    "Cot",
    "Coth",
    "Cs",
    "Csc",
    "Csch",
    "Curl",
    "DeclareOccurrence",
    "Determinant",
    "Diff",
    "Divergence",
    "Divide",
    "Domain",
    "Emptyset",
    "Eq",
    "Equivalent",
    "Eulergamma",
    "Exists",
    "Exp",
    "Exponentiale",
    "Factorial",
    "Factorof",
    "FalseType",
    "Floor",
    "Forall",
    "Gcd",
    "Geq",
    "Grad",
    "Gt",
    "Ident",
    "Image",
    "Imaginary",
    "Imaginaryi",
    "Implies",
    "In",
    "Infinity",
    "Int",
    "Integers",
    "Intersect",
    "Interval",
    "Inverse",
    "Lambda",
    "Laplacian",
    "Lcm",
    "Leq",
    "Limit",
    "Linestyle",
    "ListOrder",
    "Ln",
    "Log",
    "Lt",
    "MactionValue",
    "Maligngroup",
    "MaligngroupGroupalign",
    "MaligngroupValue",
    "Malignmark",
    "MalignmarkEdge",
    "MalignmarkValue",
    "Math",
    "MathAccent",
    "MathAccentunder",
    "MathAlign",
    "MathBevelled",
    "MathCharalign",
    "MathDenomalign",
    "MathDir",
    "MathDisplay",
    "MathDisplaystyle",
    "MathEdge",
    "MathEqualcolumns",
    "MathEqualrows",
    "MathFence",
    "MathForm",
    "MathIndentalign",
    "MathIndentalignfirst",
    "MathIndentalignlast",
    "MathInfixlinebreakstyle",
    "MathLargeop",
    "MathLinebreak",
    "MathLinebreakstyle",
    "MathLocation",
    "MathLongdivstyle",
    "MathMathvariant",
    "MathMovablelimits",
    "MathNumalign",
    "MathOverflow",
    "MathSeparator",
    "MathSide",
    "MathStackalign",
    "MathStretchy",
    "MathSymmetric",
    "MathValue",
    "Matrix",
    "Matrixrow",
    "Max",
    "Mean",
    "Median",
    "MencloseValue",
    "MerrorValue",
    "MfencedValue",
    "MfracBevelled",
    "MfracDenomalign",
    "MfracNumalign",
    "MfracValue",
    "Mglyph",
    "MglyphFontstyle",
    "MglyphFontweight",
    "MglyphMathvariant",
    "MglyphValue",
    "Mi",
    "MiDir",
    "MiFontstyle",
    "MiFontweight",
    "MiMathvariant",
    "MiValue",
    "Min",
    "Minus",
    "Mlabeledtr",
    "MlabeledtrRowalign",
    "MlabeledtrValue",
    "MlongdivLongdivstyle",
    "MlongdivValue",
    "MmultiscriptsValue",
    "Mn",
    "MnDir",
    "MnFontstyle",
    "MnFontweight",
    "MnMathvariant",
    "MnValue",
    "Mo",
    "MoAccent",
    "MoDir",
    "MoFence",
    "MoFontstyle",
    "MoFontweight",
    "MoForm",
    "MoIndentalign",
    "MoIndentalignfirst",
    "MoIndentalignlast",
    "MoLargeop",
    "MoLinebreak",
    "MoLinebreakstyle",
    "MoMathvariant",
    "MoMovablelimits",
    "MoSeparator",
    "MoStretchy",
    "MoSymmetric",
    "MoValue",
    "Mode",
    "Moment",
    "MoverAccent",
    "MoverAlign",
    "MoverValue",
    "MpaddedValue",
    "MphantomValue",
    "Mprescripts",
    "MprescriptsValue",
    "MrootValue",
    "MrowDir",
    "MrowValue",
    "Ms",
    "MsDir",
    "MsFontstyle",
    "MsFontweight",
    "MsMathvariant",
    "MsValue",
    "MscarriesLocation",
    "MscarriesValue",
    "MscarryLocation",
    "MscarryValue",
    "MsgroupValue",
    "Msline",
    "MslineValue",
    "Mspace",
    "MspaceDir",
    "MspaceFontstyle",
    "MspaceFontweight",
    "MspaceLinebreak",
    "MspaceMathvariant",
    "MspaceValue",
    "MsqrtValue",
    "MsrowValue",
    "MstackCharalign",
    "MstackStackalign",
    "MstackValue",
    "MstyleAccent",
    "MstyleAccentunder",
    "MstyleAlign",
    "MstyleBevelled",
    "MstyleCharalign",
    "MstyleDenomalign",
    "MstyleDir",
    "MstyleDisplaystyle",
    "MstyleEdge",
    "MstyleEqualcolumns",
    "MstyleEqualrows",
    "MstyleFence",
    "MstyleFontstyle",
    "MstyleFontweight",
    "MstyleForm",
    "MstyleIndentalign",
    "MstyleIndentalignfirst",
    "MstyleIndentalignlast",
    "MstyleInfixlinebreakstyle",
    "MstyleLargeop",
    "MstyleLinebreak",
    "MstyleLinebreakstyle",
    "MstyleLocation",
    "MstyleLongdivstyle",
    "MstyleMathvariant",
    "MstyleMovablelimits",
    "MstyleNumalign",
    "MstyleSeparator",
    "MstyleSide",
    "MstyleStackalign",
    "MstyleStretchy",
    "MstyleSymmetric",
    "MstyleValue",
    "MsubValue",
    "MsubsupValue",
    "MsupValue",
    "Mtable",
    "MtableDisplaystyle",
    "MtableEqualcolumns",
    "MtableEqualrows",
    "MtableSide",
    "MtableValue",
    "Mtd",
    "Mtext",
    "MtextDir",
    "MtextFontstyle",
    "MtextFontweight",
    "MtextMathvariant",
    "MtextValue",
    "Mtr",
    "MtrRowalign",
    "MtrValue",
    "MunderAccentunder",
    "MunderAlign",
    "MunderValue",
    "MunderoverAccent",
    "MunderoverAccentunder",
    "MunderoverAlign",
    "MunderoverValue",
    "Naturalnumbers",
    "Neq",
    "NoneType",
    "NoneValue",
    "Not",
    "Notanumber",
    "Notin",
    "Notprsubset",
    "Notsubset",
    "Or",
    "Outerproduct",
    "Partialdiff",
    "Pi",
    "Plus",
    "Power",
    "Primes",
    "Product",
    "Prsubset",
    "Quotient",
    "Rationals",
    "Real",
    "Reals",
    "Rem",
    "Root",
    "Scalarproduct",
    "Sdev",
    "Sec",
    "Sech",
    "Selector",
    "Sep",
    "Setdiff",
    "Share",
    "Sin",
    "Sinh",
    "Subset",
    "Sum",
    "Tan",
    "Tanh",
    "Tendsto",
    "Times",
    "Transpose",
    "TrueType",
    "UnionType",
    "Variance",
    "Vector",
    "Vectorproduct",
    "Verticalalign",
    "Xor",
]



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .abstract_text import AbstractText
from .other_abstract_type import OtherAbstractType


@dataclass
class OtherAbstract:
    type: Optional[OtherAbstractType] = field(
        default=None,
        metadata={
            "name": "Type",
            "type": "Attribute",
            "required": True,
        }
    )
    language: str = field(
        default="eng",
        metadata={
            "name": "Language",
            "type": "Attribute",
            "required": True,
        }
    )
    abstract_text: List[AbstractText] = field(
        default_factory=list,
        metadata={
            "name": "AbstractText",
            "type": "Element",
            "min_occurs": 1,
        }
    )
    copyright_information: Optional[str] = field(
        default=None,
        metadata={
            "name": "CopyrightInformation",
            "type": "Element",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List
from .pub_med_pub_date import PubMedPubDate


@dataclass
class History1:
    class Meta:
        name = "History"

    pub_med_pub_date: List[PubMedPubDate] = field(
        default_factory=list,
        metadata={
            "name": "PubMedPubDate",
            "type": "Element",
            "min_occurs": 1,
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional, Union
from .access_date import (
    Date,
    Isbn,
    Issn,
    IssnL,
    Notes,
    Permissions,
    StringDate,
)
from .article_id import ArticleId
from .article_version import ArticleVersion
from .article_version_alternatives import ArticleVersionAlternatives
from .event_desc import EventDesc
from .org.w3.xml.pkg_1998.namespace.lang_value import LangValue
from .pub_date_2 import PubDate2
from .pub_date_not_available import PubDateNotAvailable
from .self_uri import SelfUri


@dataclass
class Event:
    """
    <div> <h3>Event in Publishing History</h3> </div>
    """
    class Meta:
        name = "event"

    event_desc: Optional[EventDesc] = field(
        default=None,
        metadata={
            "name": "event-desc",
            "type": "Element",
        }
    )
    article_id: List[ArticleId] = field(
        default_factory=list,
        metadata={
            "name": "article-id",
            "type": "Element",
        }
    )
    article_version: Optional[ArticleVersion] = field(
        default=None,
        metadata={
            "name": "article-version",
            "type": "Element",
        }
    )
    article_version_alternatives: Optional[ArticleVersionAlternatives] = field(
        default=None,
        metadata={
            "name": "article-version-alternatives",
            "type": "Element",
        }
    )
    pub_date: List[PubDate2] = field(
        default_factory=list,
        metadata={
            "name": "pub-date",
            "type": "Element",
        }
    )
    pub_date_not_available: Optional[PubDateNotAvailable] = field(
        default=None,
        metadata={
            "name": "pub-date-not-available",
            "type": "Element",
        }
    )
    date: List[Date] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    string_date: List[StringDate] = field(
        default_factory=list,
        metadata={
            "name": "string-date",
            "type": "Element",
        }
    )
    issn: List[Issn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    issn_l: Optional[IssnL] = field(
        default=None,
        metadata={
            "name": "issn-l",
            "type": "Element",
        }
    )
    isbn: List[Isbn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    permissions: Optional[Permissions] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notes: List[Notes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    self_uri: List[SelfUri] = field(
        default_factory=list,
        metadata={
            "name": "self-uri",
            "type": "Element",
        }
    )
    event_type: Optional[str] = field(
        default=None,
        metadata={
            "name": "event-type",
            "type": "Attribute",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    specific_use: Optional[str] = field(
        default=None,
        metadata={
            "name": "specific-use",
            "type": "Attribute",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )
    lang: Optional[Union[str, LangValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .affiliation import Affiliation
from .identifier import Identifier


@dataclass
class AffiliationInfo:
    affiliation: Optional[Affiliation] = field(
        default=None,
        metadata={
            "name": "Affiliation",
            "type": "Element",
            "required": True,
        }
    )
    identifier: List[Identifier] = field(
        default_factory=list,
        metadata={
            "name": "Identifier",
            "type": "Element",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .access_date import (
    Aff,
    AffAlternatives,
    ContribGroup,
    Isbn,
    Issn,
    IssnL,
    Notes,
)
from .custom_meta_group import CustomMetaGroup
from .journal_id import JournalId
from .journal_title_group import JournalTitleGroup
from .publisher_2 import Publisher2
from .self_uri import SelfUri


@dataclass
class JournalMeta:
    """
    <div> <h3>Journal Metadata</h3> </div>
    """
    class Meta:
        name = "journal-meta"

    journal_id: List[JournalId] = field(
        default_factory=list,
        metadata={
            "name": "journal-id",
            "type": "Element",
        }
    )
    journal_title_group: List[JournalTitleGroup] = field(
        default_factory=list,
        metadata={
            "name": "journal-title-group",
            "type": "Element",
        }
    )
    contrib_group: List[ContribGroup] = field(
        default_factory=list,
        metadata={
            "name": "contrib-group",
            "type": "Element",
        }
    )
    aff: List[Aff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    aff_alternatives: List[AffAlternatives] = field(
        default_factory=list,
        metadata={
            "name": "aff-alternatives",
            "type": "Element",
        }
    )
    issn: List[Issn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    issn_l: Optional[IssnL] = field(
        default=None,
        metadata={
            "name": "issn-l",
            "type": "Element",
        }
    )
    isbn: List[Isbn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    publisher: Optional[Publisher2] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notes: List[Notes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    self_uri: List[SelfUri] = field(
        default_factory=list,
        metadata={
            "name": "self-uri",
            "type": "Element",
        }
    )
    custom_meta_group: Optional[CustomMetaGroup] = field(
        default=None,
        metadata={
            "name": "custom-meta-group",
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )



from enum import Enum

__NAMESPACE__ = "http://www.w3.org/1998/Math/MathML"


class MathOverflow(Enum):
    LINEBREAK = "linebreak"
    SCROLL = "scroll"
    ELIDE = "elide"
    TRUNCATE = "truncate"
    SCALE = "scale"



from .abbrev_journal_title import AbbrevJournalTitle
from .abstract_1 import Abstract1
from .abstract_text import AbstractText
from .abstract_text_nlm_category import AbstractTextNlmCategory
from .access_date import (
    Abbrev,
    Abstract2,
    AccessDate,
    Ack,
    AddrLine,
    Address,
    Aff,
    AffAlternatives,
    AltTitle,
    Alternatives,
    Annotation,
    Anonymous,
    Answer,
    AnswerSet,
    Array,
    ArticleTitle,
    Attrib,
    AuthorComment,
    AwardId,
    Bio,
    BlockAlternatives,
    Bold,
    BoxedText,
    Caption,
    ChapterTitle,
    ChemStruct,
    ChemStructWrap,
    CitationAlternatives,
    Code,
    Collab,
    CollabAlternatives,
    Comment,
    CompoundKwd,
    CompoundKwdPart,
    CompoundSubject,
    CompoundSubjectPart,
    ConfAcronym,
    ConfDate,
    ConfLoc,
    ConfName,
    ConfSponsor,
    Contrib,
    ContribGroup,
    CopyrightHolder,
    CopyrightStatement,
    Country,
    DataTitle,
    Date,
    DateInCitation,
    Def,
    DefHead,
    DefItem,
    DefList,
    Degrees,
    DispFormulaGroup,
    DispFormula2,
    DispQuote,
    Edition,
    ElementCitation,
    Email,
    Etal,
    Explanation,
    ExtLink,
    Fax,
    Fig,
    FigGroup,
    FixedCase,
    Fn,
    FnGroup,
    FundingSource,
    GivenNames,
    Glossary,
    Gov,
    Graphic,
    IndexTerm,
    InlineFormula,
    InlineGraphic,
    InlineMedia,
    InlineSupplementaryMaterial,
    Institution,
    InstitutionWrap,
    Isbn,
    Issn,
    IssnL,
    Issue,
    IssuePart,
    IssueTitle,
    Italic,
    Kwd,
    KwdGroup,
    Label,
    License,
    LicenseP,
    ListType,
    ListItem,
    LongDesc,
    Media,
    MixedCitation,
    Monospace,
    Name,
    NameAlternatives,
    NamedContent,
    NestedKwd,
    NlmCitation,
    Note,
    Notes,
    OnBehalfOf,
    OpenAccess,
    Option,
    Overline,
    P,
    PartTitle,
    Patent,
    Permissions,
    PersonGroup,
    Phone,
    Prefix,
    Preformat,
    Price,
    PrivateChar,
    Product,
    PublisherLoc,
    PublisherName,
    Question,
    QuestionPreamble,
    QuestionWrap,
    QuestionWrapGroup,
    Rb,
    Ref,
    RefList,
    RelatedArticle,
    RelatedObject,
    Role,
    Roman,
    Ruby,
    SansSerif,
    Sc,
    Sec,
    SecMeta,
    See,
    SeeAlso,
    Series,
    Size,
    Source,
    Speaker,
    Speech,
    Statement,
    Std,
    StdOrganization,
    Strike,
    StringDate,
    StringName,
    StyledContent,
    Sub,
    SubjGroup,
    Subject,
    Subtitle,
    Suffix,
    Sup,
    Supplement,
    SupplementaryMaterial,
    Surname,
    Table,
    TableWrap,
    TableWrapFoot,
    TableWrapGroup,
    Target,
    Tbody,
    Td,
    Term,
    TermHead,
    TextualForm,
    Tfoot,
    Th,
    Thead,
    TimeStamp,
    Title,
    Tr,
    TransSource,
    TransTitle,
    Underline,
    UnstructuredKwdGroup,
    Uri,
    VerseGroup,
    VerseLine,
    Version,
    Volume,
    VolumeId,
    VolumeSeries,
    X,
    Xref,
)
from .accession_number_list import AccessionNumberList
from .affiliation import Affiliation
from .affiliation_info import AffiliationInfo
from .alt_text import AltText
from .app import App
from .app_group import AppGroup
from .array_orientation import ArrayOrientation
from .article_1 import Article1
from .article_2 import Article2
from .article_categories import ArticleCategories
from .article_date import ArticleDate
from .article_dtd_version import ArticleDtdVersion
from .article_id import ArticleId
from .article_id_1 import ArticleId1
from .article_id_id_type import ArticleIdIdType
from .article_id_list import ArticleIdList
from .article_meta import ArticleMeta
from .article_pub_model import ArticlePubModel
from .article_title_1 import ArticleTitle1
from .article_version import ArticleVersion
from .article_version_alternatives import ArticleVersionAlternatives
from .author import Author
from .author_equal_contrib import AuthorEqualContrib
from .author_list import AuthorList
from .author_list_complete_yn import AuthorListCompleteYn
from .author_list_type import AuthorListType
from .author_notes import AuthorNotes
from .author_valid_yn import AuthorValidYn
from .award_desc import AwardDesc
from .award_group import AwardGroup
from .award_name import AwardName
from .back import Back
from .beginning_date import BeginningDate
from .body import Body
from .bold_toggle import BoldToggle
from .book import Book
from .book_document import BookDocument
from .book_document_set import BookDocumentSet
from .book_title import BookTitle
from .boxed_text_orientation import BoxedTextOrientation
from .boxed_text_position import BoxedTextPosition
from .break_mod import Break
from .chem_struct_wrap_orientation import ChemStructWrapOrientation
from .chem_struct_wrap_position import ChemStructWrapPosition
from .chemical import Chemical
from .chemical_list import ChemicalList
from .citation import Citation
from .city import City
from .code_executable import CodeExecutable
from .code_orientation import CodeOrientation
from .code_position import CodePosition
from .coi_statement import CoiStatement
from .col import Col
from .col_align import ColAlign
from .col_valign import ColValign
from .colgroup import Colgroup
from .colgroup_align import ColgroupAlign
from .colgroup_valign import ColgroupValign
from .collection_title import CollectionTitle
from .collective_name import CollectiveName
from .comments_corrections import CommentsCorrections
from .comments_corrections_list import CommentsCorrectionsList
from .comments_corrections_ref_type import CommentsCorrectionsRefType
from .conf_num import ConfNum
from .conf_theme import ConfTheme
from .conference import Conference
from .contrib_corresp import ContribCorresp
from .contrib_deceased import ContribDeceased
from .contrib_equal_contrib import ContribEqualContrib
from .contrib_id import ContribId
from .contrib_id_authenticated import ContribIdAuthenticated
from .contributed_resource_group import ContributedResourceGroup
from .contribution_date import ContributionDate
from .copyright_year import CopyrightYear
from .corresp import Corresp
from .count import Count
from .counts import Counts
from .custom_meta import CustomMeta
from .custom_meta_group import CustomMetaGroup
from .data_bank import DataBank
from .data_bank_list import DataBankList
from .data_bank_list_complete_yn import DataBankListCompleteYn
from .date_completed import DateCompleted
from .date_revised import DateRevised
from .day import Day
from .delete_citation import DeleteCitation
from .delete_document import DeleteDocument
from .descriptor_name import DescriptorName
from .descriptor_name_major_topic_yn import DescriptorNameMajorTopicYn
from .descriptor_name_type import DescriptorNameType
from .disp_formula_1 import DispFormula1
from .elocation_id import ElocationId
from .elocation_id_1 import ElocationId1
from .elocation_id_eid_type import ElocationIdEidType
from .elocation_id_valid_yn import ElocationIdValidYn
from .ending_date import EndingDate
from .equation_count import EquationCount
from .era import Era
from .event import Event
from .event_desc import EventDesc
from .extended_by import ExtendedBy
from .fig_count import FigCount
from .fig_group_orientation import FigGroupOrientation
from .fig_group_position import FigGroupPosition
from .fig_orientation import FigOrientation
from .fig_position import FigPosition
from .floats_group import FloatsGroup
from .fpage import Fpage
from .front import Front
from .front_stub import FrontStub
from .funding_group import FundingGroup
from .funding_statement import FundingStatement
from .gene_symbol_list import GeneSymbolList
from .general_note import GeneralNote
from .general_note_owner import GeneralNoteOwner
from .glyph_data import GlyphData
from .glyph_ref import GlyphRef
from .grant import Grant
from .grant_list import GrantList
from .grant_list_complete_yn import GrantListCompleteYn
from .graphic_orientation import GraphicOrientation
from .graphic_position import GraphicPosition
from .history_1 import History1
from .history_2 import History2
from .hr import Hr
from .identifier import Identifier
from .index_term_range_end import IndexTermRangeEnd
from .institution_id import InstitutionId
from .investigator import Investigator
from .investigator_list import InvestigatorList
from .investigator_valid_yn import InvestigatorValidYn
from .issn_1 import Issn1
from .issn_issn_type import IssnIssnType
from .issue_id import IssueId
from .issue_sponsor import IssueSponsor
from .issue_subtitle import IssueSubtitle
from .issue_title_group import IssueTitleGroup
from .italic_toggle import ItalicToggle
from .item_list import ItemList
from .journal import Journal
from .journal_id import JournalId
from .journal_issue import JournalIssue
from .journal_issue_cited_medium import JournalIssueCitedMedium
from .journal_meta import JournalMeta
from .journal_subtitle import JournalSubtitle
from .journal_title import JournalTitle
from .journal_title_group import JournalTitleGroup
from .keyword import Keyword
from .keyword_list import KeywordList
from .keyword_list_owner import KeywordListOwner
from .keyword_major_topic_yn import KeywordMajorTopicYn
from .location_label import LocationLabel
from .location_label_type import LocationLabelType
from .lpage import Lpage
from .media_orientation import MediaOrientation
from .media_position import MediaPosition
from .medline_citation import MedlineCitation
from .medline_citation_owner import MedlineCitationOwner
from .medline_citation_status import MedlineCitationStatus
from .medline_journal_info import MedlineJournalInfo
from .mesh_heading import MeshHeading
from .mesh_heading_list import MeshHeadingList
from .meta_name import MetaName
from .meta_value import MetaValue
from .milestone_end import MilestoneEnd
from .milestone_start import MilestoneStart
from .monospace_toggle import MonospaceToggle
from .month import Month
from .name_name_style import NameNameStyle
from .name_of_substance import NameOfSubstance
from .object_id import ObjectId
from .object_list import ObjectList
from .object_mod import Object
from .option_correct import OptionCorrect
from .other_abstract import OtherAbstract
from .other_abstract_type import OtherAbstractType
from .other_id import OtherId
from .other_id_source import OtherIdSource
from .overline_end import OverlineEnd
from .overline_start import OverlineStart
from .overline_toggle import OverlineToggle
from .page_count import PageCount
from .page_range import PageRange
from .pagination import Pagination
from .param import Param
from .personal_name_subject import PersonalNameSubject
from .personal_name_subject_list import PersonalNameSubjectList
from .pmid import Pmid
from .postal_code import PostalCode
from .preformat_orientation import PreformatOrientation
from .preformat_position import PreformatPosition
from .principal_award_recipient import PrincipalAwardRecipient
from .principal_investigator import PrincipalInvestigator
from .processing_meta import ProcessingMeta
from .processing_meta_base_tagset import ProcessingMetaBaseTagset
from .processing_meta_mathml_version import ProcessingMetaMathmlVersion
from .processing_meta_table_model import ProcessingMetaTableModel
from .processing_meta_tagset_family import ProcessingMetaTagsetFamily
from .pub_date_1 import PubDate1
from .pub_date_2 import PubDate2
from .pub_date_not_available import PubDateNotAvailable
from .pub_history import PubHistory
from .pub_id import PubId
from .pub_med_pub_date import PubMedPubDate
from .pub_med_pub_date_pub_status import PubMedPubDatePubStatus
from .publication_type import PublicationType
from .publication_type_list import PublicationTypeList
from .publisher_1 import Publisher1
from .publisher_2 import Publisher2
from .publisher_name_1 import PublisherName1
from .pubmed_article import PubmedArticle
from .pubmed_article_set import PubmedArticleSet
from .pubmed_book_article import PubmedBookArticle
from .pubmed_book_article_set import PubmedBookArticleSet
from .pubmed_book_data import PubmedBookData
from .pubmed_data import PubmedData
from .qualifier_name import QualifierName
from .qualifier_name_major_topic_yn import QualifierNameMajorTopicYn
from .question_question_response_type import QuestionQuestionResponseType
from .ref_count import RefCount
from .reference import Reference
from .reference_list import ReferenceList
from .resource_group import ResourceGroup
from .resource_id import ResourceId
from .resource_name import ResourceName
from .resource_wrap import ResourceWrap
from .response import Response
from .restricted_by import RestrictedBy
from .roman_toggle import RomanToggle
from .rp import Rp
from .rt import Rt
from .sans_serif_toggle import SansSerifToggle
from .sc_toggle import ScToggle
from .season import Season
from .section import Section
from .section_title import SectionTitle
from .sections import Sections
from .self_uri import SelfUri
from .series_text import SeriesText
from .series_title import SeriesTitle
from .sig import Sig
from .sig_block import SigBlock
from .state import State
from .strike_toggle import StrikeToggle
from .string_conf import StringConf
from .string_name_name_style import StringNameNameStyle
from .styled_content_toggle import StyledContentToggle
from .sub_1 import Sub1
from .sub_arrange import SubArrange
from .sub_article import SubArticle
from .suffix_1 import Suffix1
from .sup_1 import Sup1
from .sup_arrange import SupArrange
from .suppl_mesh_list import SupplMeshList
from .suppl_mesh_name import SupplMeshName
from .suppl_mesh_name_type import SupplMeshNameType
from .supplementary_material_orientation import SupplementaryMaterialOrientation
from .supplementary_material_position import SupplementaryMaterialPosition
from .support_description import SupportDescription
from .support_group import SupportGroup
from .support_source import SupportSource
from .table_count import TableCount
from .table_frame import TableFrame
from .table_rules import TableRules
from .table_wrap_group_orientation import TableWrapGroupOrientation
from .table_wrap_group_position import TableWrapGroupPosition
from .table_wrap_orientation import TableWrapOrientation
from .table_wrap_position import TableWrapPosition
from .tbody_align import TbodyAlign
from .tbody_valign import TbodyValign
from .td_align import TdAlign
from .td_scope import TdScope
from .td_valign import TdValign
from .tex_math import TexMath
from .tex_math_notation import TexMathNotation
from .tfoot_align import TfootAlign
from .tfoot_valign import TfootValign
from .th_align import ThAlign
from .th_scope import ThScope
from .th_valign import ThValign
from .thead_align import TheadAlign
from .thead_valign import TheadValign
from .title_group import TitleGroup
from .tr_align import TrAlign
from .tr_valign import TrValign
from .trans_abstract import TransAbstract
from .trans_subtitle import TransSubtitle
from .trans_title_group import TransTitleGroup
from .u import (
    B,
    I,
    U,
)
from .underline_end import UnderlineEnd
from .underline_start import UnderlineStart
from .underline_toggle import UnderlineToggle
from .url import Url
from .url_lang import UrlLang
from .url_type import UrlType
from .vernacular_title import VernacularTitle
from .volume_issue_group import VolumeIssueGroup
from .volume_title import VolumeTitle
from .word_count import WordCount
from .xs_pattern import XsPattern
from .year import Year

__all__ = [
    "AbbrevJournalTitle",
    "Abstract1",
    "AbstractText",
    "AbstractTextNlmCategory",
    "Abbrev",
    "Abstract2",
    "AccessDate",
    "Ack",
    "AddrLine",
    "Address",
    "Aff",
    "AffAlternatives",
    "AltTitle",
    "Alternatives",
    "Annotation",
    "Anonymous",
    "Answer",
    "AnswerSet",
    "Array",
    "ArticleTitle",
    "Attrib",
    "AuthorComment",
    "AwardId",
    "Bio",
    "BlockAlternatives",
    "Bold",
    "BoxedText",
    "Caption",
    "ChapterTitle",
    "ChemStruct",
    "ChemStructWrap",
    "CitationAlternatives",
    "Code",
    "Collab",
    "CollabAlternatives",
    "Comment",
    "CompoundKwd",
    "CompoundKwdPart",
    "CompoundSubject",
    "CompoundSubjectPart",
    "ConfAcronym",
    "ConfDate",
    "ConfLoc",
    "ConfName",
    "ConfSponsor",
    "Contrib",
    "ContribGroup",
    "CopyrightHolder",
    "CopyrightStatement",
    "Country",
    "DataTitle",
    "Date",
    "DateInCitation",
    "Def",
    "DefHead",
    "DefItem",
    "DefList",
    "Degrees",
    "DispFormulaGroup",
    "DispFormula2",
    "DispQuote",
    "Edition",
    "ElementCitation",
    "Email",
    "Etal",
    "Explanation",
    "ExtLink",
    "Fax",
    "Fig",
    "FigGroup",
    "FixedCase",
    "Fn",
    "FnGroup",
    "FundingSource",
    "GivenNames",
    "Glossary",
    "Gov",
    "Graphic",
    "IndexTerm",
    "InlineFormula",
    "InlineGraphic",
    "InlineMedia",
    "InlineSupplementaryMaterial",
    "Institution",
    "InstitutionWrap",
    "Isbn",
    "Issn",
    "IssnL",
    "Issue",
    "IssuePart",
    "IssueTitle",
    "Italic",
    "Kwd",
    "KwdGroup",
    "Label",
    "License",
    "LicenseP",
    "ListType",
    "ListItem",
    "LongDesc",
    "Media",
    "MixedCitation",
    "Monospace",
    "Name",
    "NameAlternatives",
    "NamedContent",
    "NestedKwd",
    "NlmCitation",
    "Note",
    "Notes",
    "OnBehalfOf",
    "OpenAccess",
    "Option",
    "Overline",
    "P",
    "PartTitle",
    "Patent",
    "Permissions",
    "PersonGroup",
    "Phone",
    "Prefix",
    "Preformat",
    "Price",
    "PrivateChar",
    "Product",
    "PublisherLoc",
    "PublisherName",
    "Question",
    "QuestionPreamble",
    "QuestionWrap",
    "QuestionWrapGroup",
    "Rb",
    "Ref",
    "RefList",
    "RelatedArticle",
    "RelatedObject",
    "Role",
    "Roman",
    "Ruby",
    "SansSerif",
    "Sc",
    "Sec",
    "SecMeta",
    "See",
    "SeeAlso",
    "Series",
    "Size",
    "Source",
    "Speaker",
    "Speech",
    "Statement",
    "Std",
    "StdOrganization",
    "Strike",
    "StringDate",
    "StringName",
    "StyledContent",
    "Sub",
    "SubjGroup",
    "Subject",
    "Subtitle",
    "Suffix",
    "Sup",
    "Supplement",
    "SupplementaryMaterial",
    "Surname",
    "Table",
    "TableWrap",
    "TableWrapFoot",
    "TableWrapGroup",
    "Target",
    "Tbody",
    "Td",
    "Term",
    "TermHead",
    "TextualForm",
    "Tfoot",
    "Th",
    "Thead",
    "TimeStamp",
    "Title",
    "Tr",
    "TransSource",
    "TransTitle",
    "Underline",
    "UnstructuredKwdGroup",
    "Uri",
    "VerseGroup",
    "VerseLine",
    "Version",
    "Volume",
    "VolumeId",
    "VolumeSeries",
    "X",
    "Xref",
    "AccessionNumberList",
    "Affiliation",
    "AffiliationInfo",
    "AltText",
    "App",
    "AppGroup",
    "ArrayOrientation",
    "Article1",
    "Article2",
    "ArticleCategories",
    "ArticleDate",
    "ArticleDtdVersion",
    "ArticleId",
    "ArticleId1",
    "ArticleIdIdType",
    "ArticleIdList",
    "ArticleMeta",
    "ArticlePubModel",
    "ArticleTitle1",
    "ArticleVersion",
    "ArticleVersionAlternatives",
    "Author",
    "AuthorEqualContrib",
    "AuthorList",
    "AuthorListCompleteYn",
    "AuthorListType",
    "AuthorNotes",
    "AuthorValidYn",
    "AwardDesc",
    "AwardGroup",
    "AwardName",
    "Back",
    "BeginningDate",
    "Body",
    "BoldToggle",
    "Book",
    "BookDocument",
    "BookDocumentSet",
    "BookTitle",
    "BoxedTextOrientation",
    "BoxedTextPosition",
    "Break",
    "ChemStructWrapOrientation",
    "ChemStructWrapPosition",
    "Chemical",
    "ChemicalList",
    "Citation",
    "City",
    "CodeExecutable",
    "CodeOrientation",
    "CodePosition",
    "CoiStatement",
    "Col",
    "ColAlign",
    "ColValign",
    "Colgroup",
    "ColgroupAlign",
    "ColgroupValign",
    "CollectionTitle",
    "CollectiveName",
    "CommentsCorrections",
    "CommentsCorrectionsList",
    "CommentsCorrectionsRefType",
    "ConfNum",
    "ConfTheme",
    "Conference",
    "ContribCorresp",
    "ContribDeceased",
    "ContribEqualContrib",
    "ContribId",
    "ContribIdAuthenticated",
    "ContributedResourceGroup",
    "ContributionDate",
    "CopyrightYear",
    "Corresp",
    "Count",
    "Counts",
    "CustomMeta",
    "CustomMetaGroup",
    "DataBank",
    "DataBankList",
    "DataBankListCompleteYn",
    "DateCompleted",
    "DateRevised",
    "Day",
    "DeleteCitation",
    "DeleteDocument",
    "DescriptorName",
    "DescriptorNameMajorTopicYn",
    "DescriptorNameType",
    "DispFormula1",
    "ElocationId",
    "ElocationId1",
    "ElocationIdEidType",
    "ElocationIdValidYn",
    "EndingDate",
    "EquationCount",
    "Era",
    "Event",
    "EventDesc",
    "ExtendedBy",
    "FigCount",
    "FigGroupOrientation",
    "FigGroupPosition",
    "FigOrientation",
    "FigPosition",
    "FloatsGroup",
    "Fpage",
    "Front",
    "FrontStub",
    "FundingGroup",
    "FundingStatement",
    "GeneSymbolList",
    "GeneralNote",
    "GeneralNoteOwner",
    "GlyphData",
    "GlyphRef",
    "Grant",
    "GrantList",
    "GrantListCompleteYn",
    "GraphicOrientation",
    "GraphicPosition",
    "History1",
    "History2",
    "Hr",
    "Identifier",
    "IndexTermRangeEnd",
    "InstitutionId",
    "Investigator",
    "InvestigatorList",
    "InvestigatorValidYn",
    "Issn1",
    "IssnIssnType",
    "IssueId",
    "IssueSponsor",
    "IssueSubtitle",
    "IssueTitleGroup",
    "ItalicToggle",
    "ItemList",
    "Journal",
    "JournalId",
    "JournalIssue",
    "JournalIssueCitedMedium",
    "JournalMeta",
    "JournalSubtitle",
    "JournalTitle",
    "JournalTitleGroup",
    "Keyword",
    "KeywordList",
    "KeywordListOwner",
    "KeywordMajorTopicYn",
    "LocationLabel",
    "LocationLabelType",
    "Lpage",
    "MediaOrientation",
    "MediaPosition",
    "MedlineCitation",
    "MedlineCitationOwner",
    "MedlineCitationStatus",
    "MedlineJournalInfo",
    "MeshHeading",
    "MeshHeadingList",
    "MetaName",
    "MetaValue",
    "MilestoneEnd",
    "MilestoneStart",
    "MonospaceToggle",
    "Month",
    "NameNameStyle",
    "NameOfSubstance",
    "ObjectId",
    "ObjectList",
    "Object",
    "OptionCorrect",
    "OtherAbstract",
    "OtherAbstractType",
    "OtherId",
    "OtherIdSource",
    "OverlineEnd",
    "OverlineStart",
    "OverlineToggle",
    "PageCount",
    "PageRange",
    "Pagination",
    "Param",
    "PersonalNameSubject",
    "PersonalNameSubjectList",
    "Pmid",
    "PostalCode",
    "PreformatOrientation",
    "PreformatPosition",
    "PrincipalAwardRecipient",
    "PrincipalInvestigator",
    "ProcessingMeta",
    "ProcessingMetaBaseTagset",
    "ProcessingMetaMathmlVersion",
    "ProcessingMetaTableModel",
    "ProcessingMetaTagsetFamily",
    "PubDate1",
    "PubDate2",
    "PubDateNotAvailable",
    "PubHistory",
    "PubId",
    "PubMedPubDate",
    "PubMedPubDatePubStatus",
    "PublicationType",
    "PublicationTypeList",
    "Publisher1",
    "Publisher2",
    "PublisherName1",
    "PubmedArticle",
    "PubmedArticleSet",
    "PubmedBookArticle",
    "PubmedBookArticleSet",
    "PubmedBookData",
    "PubmedData",
    "QualifierName",
    "QualifierNameMajorTopicYn",
    "QuestionQuestionResponseType",
    "RefCount",
    "Reference",
    "ReferenceList",
    "ResourceGroup",
    "ResourceId",
    "ResourceName",
    "ResourceWrap",
    "Response",
    "RestrictedBy",
    "RomanToggle",
    "Rp",
    "Rt",
    "SansSerifToggle",
    "ScToggle",
    "Season",
    "Section",
    "SectionTitle",
    "Sections",
    "SelfUri",
    "SeriesText",
    "SeriesTitle",
    "Sig",
    "SigBlock",
    "State",
    "StrikeToggle",
    "StringConf",
    "StringNameNameStyle",
    "StyledContentToggle",
    "Sub1",
    "SubArrange",
    "SubArticle",
    "Suffix1",
    "Sup1",
    "SupArrange",
    "SupplMeshList",
    "SupplMeshName",
    "SupplMeshNameType",
    "SupplementaryMaterialOrientation",
    "SupplementaryMaterialPosition",
    "SupportDescription",
    "SupportGroup",
    "SupportSource",
    "TableCount",
    "TableFrame",
    "TableRules",
    "TableWrapGroupOrientation",
    "TableWrapGroupPosition",
    "TableWrapOrientation",
    "TableWrapPosition",
    "TbodyAlign",
    "TbodyValign",
    "TdAlign",
    "TdScope",
    "TdValign",
    "TexMath",
    "TexMathNotation",
    "TfootAlign",
    "TfootValign",
    "ThAlign",
    "ThScope",
    "ThValign",
    "TheadAlign",
    "TheadValign",
    "TitleGroup",
    "TrAlign",
    "TrValign",
    "TransAbstract",
    "TransSubtitle",
    "TransTitleGroup",
    "B",
    "I",
    "U",
    "UnderlineEnd",
    "UnderlineStart",
    "UnderlineToggle",
    "Url",
    "UrlLang",
    "UrlType",
    "VernacularTitle",
    "VolumeIssueGroup",
    "VolumeTitle",
    "WordCount",
    "XsPattern",
    "Year",
]



from enum import Enum

__NAMESPACE__ = "http://www.w3.org/1998/Math/MathML"


class MspaceMathvariant(Enum):
    NORMAL = "normal"
    BOLD = "bold"
    ITALIC = "italic"
    BOLD_ITALIC = "bold-italic"
    DOUBLE_STRUCK = "double-struck"
    BOLD_FRAKTUR = "bold-fraktur"
    SCRIPT = "script"
    BOLD_SCRIPT = "bold-script"
    FRAKTUR = "fraktur"
    SANS_SERIF = "sans-serif"
    BOLD_SANS_SERIF = "bold-sans-serif"
    SANS_SERIF_ITALIC = "sans-serif-italic"
    SANS_SERIF_BOLD_ITALIC = "sans-serif-bold-italic"
    MONOSPACE = "monospace"
    INITIAL = "initial"
    TAILED = "tailed"
    LOOPED = "looped"
    STRETCHED = "stretched"



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List
from .object_mod import Object


@dataclass
class ObjectList:
    object_value: List[Object] = field(
        default_factory=list,
        metadata={
            "name": "Object",
            "type": "Element",
            "min_occurs": 1,
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional
from .article_id_list import ArticleIdList
from .history_1 import History1
from .object_list import ObjectList


@dataclass
class PubmedBookData:
    history: Optional[History1] = field(
        default=None,
        metadata={
            "name": "History",
            "type": "Element",
        }
    )
    publication_status: Optional[str] = field(
        default=None,
        metadata={
            "name": "PublicationStatus",
            "type": "Element",
            "required": True,
        }
    )
    article_id_list: Optional[ArticleIdList] = field(
        default=None,
        metadata={
            "name": "ArticleIdList",
            "type": "Element",
            "required": True,
        }
    )
    object_list: Optional[ObjectList] = field(
        default=None,
        metadata={
            "name": "ObjectList",
            "type": "Element",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List


@dataclass
class GeneSymbolList:
    gene_symbol: List[str] = field(
        default_factory=list,
        metadata={
            "name": "GeneSymbol",
            "type": "Element",
            "min_occurs": 1,
        }
    )



from enum import Enum

__NAMESPACE__ = "http://www.w3.org/1999/xlink"


class TypeValue(Enum):
    SIMPLE = "simple"
    EXTENDED = "extended"
    LOCATOR = "locator"
    ARC = "arc"
    RESOURCE = "resource"
    TITLE = "title"
    NONE = "none"



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .location_label import LocationLabel
from .section_title import SectionTitle


@dataclass
class Section:
    location_label: Optional[LocationLabel] = field(
        default=None,
        metadata={
            "name": "LocationLabel",
            "type": "Element",
        }
    )
    section_title: Optional[SectionTitle] = field(
        default=None,
        metadata={
            "name": "SectionTitle",
            "type": "Element",
            "required": True,
        }
    )
    section: List["Section"] = field(
        default_factory=list,
        metadata={
            "name": "Section",
            "type": "Element",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional
from .medline_citation import MedlineCitation
from .pubmed_data import PubmedData


@dataclass
class PubmedArticle:
    medline_citation: Optional[MedlineCitation] = field(
        default=None,
        metadata={
            "name": "MedlineCitation",
            "type": "Element",
            "required": True,
        }
    )
    pubmed_data: Optional[PubmedData] = field(
        default=None,
        metadata={
            "name": "PubmedData",
            "type": "Element",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional, Union
from .access_date import (
    Issue,
    IssuePart,
    IssueTitle,
    Volume,
    VolumeId,
    VolumeSeries,
)
from .issue_id import IssueId
from .issue_sponsor import IssueSponsor
from .issue_title_group import IssueTitleGroup
from .org.w3.xml.pkg_1998.namespace.lang_value import LangValue


@dataclass
class VolumeIssueGroup:
    """
    <div> <h3>Translated Title Group</h3> </div>
    """
    class Meta:
        name = "volume-issue-group"

    volume: List[Volume] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    volume_id: List[VolumeId] = field(
        default_factory=list,
        metadata={
            "name": "volume-id",
            "type": "Element",
        }
    )
    volume_series: Optional[VolumeSeries] = field(
        default=None,
        metadata={
            "name": "volume-series",
            "type": "Element",
        }
    )
    issue: List[Issue] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    issue_id: List[IssueId] = field(
        default_factory=list,
        metadata={
            "name": "issue-id",
            "type": "Element",
        }
    )
    issue_title: List[IssueTitle] = field(
        default_factory=list,
        metadata={
            "name": "issue-title",
            "type": "Element",
        }
    )
    issue_title_group: List[IssueTitleGroup] = field(
        default_factory=list,
        metadata={
            "name": "issue-title-group",
            "type": "Element",
        }
    )
    issue_sponsor: List[IssueSponsor] = field(
        default_factory=list,
        metadata={
            "name": "issue-sponsor",
            "type": "Element",
        }
    )
    issue_part: Optional[IssuePart] = field(
        default=None,
        metadata={
            "name": "issue-part",
            "type": "Element",
        }
    )
    content_type: Optional[str] = field(
        default=None,
        metadata={
            "name": "content-type",
            "type": "Attribute",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    specific_use: Optional[str] = field(
        default=None,
        metadata={
            "name": "specific-use",
            "type": "Attribute",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )
    lang: Optional[Union[str, LangValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .access_date import (
    Alternatives,
    BlockAlternatives,
    BoxedText,
    ChemStructWrap,
    Code,
    Fig,
    FigGroup,
    Graphic,
    Media,
    Preformat,
    SupplementaryMaterial,
    TableWrap,
    TableWrapGroup,
)


@dataclass
class FloatsGroup:
    """
    <div> <h3>Floats Group</h3> </div>
    """
    class Meta:
        name = "floats-group"

    alternatives: List[Alternatives] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    block_alternatives: List[BlockAlternatives] = field(
        default_factory=list,
        metadata={
            "name": "block-alternatives",
            "type": "Element",
        }
    )
    boxed_text: List[BoxedText] = field(
        default_factory=list,
        metadata={
            "name": "boxed-text",
            "type": "Element",
        }
    )
    chem_struct_wrap: List[ChemStructWrap] = field(
        default_factory=list,
        metadata={
            "name": "chem-struct-wrap",
            "type": "Element",
        }
    )
    code: List[Code] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    fig: List[Fig] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    fig_group: List[FigGroup] = field(
        default_factory=list,
        metadata={
            "name": "fig-group",
            "type": "Element",
        }
    )
    graphic: List[Graphic] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    media: List[Media] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    preformat: List[Preformat] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    supplementary_material: List[SupplementaryMaterial] = field(
        default_factory=list,
        metadata={
            "name": "supplementary-material",
            "type": "Element",
        }
    )
    table_wrap: List[TableWrap] = field(
        default_factory=list,
        metadata={
            "name": "table-wrap",
            "type": "Element",
        }
    )
    table_wrap_group: List[TableWrapGroup] = field(
        default_factory=list,
        metadata={
            "name": "table-wrap-group",
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional
from .accession_number_list import AccessionNumberList


@dataclass
class DataBank:
    data_bank_name: Optional[str] = field(
        default=None,
        metadata={
            "name": "DataBankName",
            "type": "Element",
            "required": True,
        }
    )
    accession_number_list: Optional[AccessionNumberList] = field(
        default=None,
        metadata={
            "name": "AccessionNumberList",
            "type": "Element",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .descriptor_name import DescriptorName
from .qualifier_name import QualifierName


@dataclass
class MeshHeading:
    descriptor_name: Optional[DescriptorName] = field(
        default=None,
        metadata={
            "name": "DescriptorName",
            "type": "Element",
            "required": True,
        }
    )
    qualifier_name: List[QualifierName] = field(
        default_factory=list,
        metadata={
            "name": "QualifierName",
            "type": "Element",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .book_document import BookDocument
from .delete_document import DeleteDocument


@dataclass
class BookDocumentSet:
    book_document: List[BookDocument] = field(
        default_factory=list,
        metadata={
            "name": "BookDocument",
            "type": "Element",
        }
    )
    delete_document: Optional[DeleteDocument] = field(
        default=None,
        metadata={
            "name": "DeleteDocument",
            "type": "Element",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .count import Count
from .equation_count import EquationCount
from .fig_count import FigCount
from .page_count import PageCount
from .ref_count import RefCount
from .table_count import TableCount
from .word_count import WordCount


@dataclass
class Counts:
    """
    <div> <h3>Counts</h3> </div>
    """
    class Meta:
        name = "counts"

    count: List[Count] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    fig_count: Optional[FigCount] = field(
        default=None,
        metadata={
            "name": "fig-count",
            "type": "Element",
        }
    )
    table_count: Optional[TableCount] = field(
        default=None,
        metadata={
            "name": "table-count",
            "type": "Element",
        }
    )
    equation_count: Optional[EquationCount] = field(
        default=None,
        metadata={
            "name": "equation-count",
            "type": "Element",
        }
    )
    ref_count: Optional[RefCount] = field(
        default=None,
        metadata={
            "name": "ref-count",
            "type": "Element",
        }
    )
    page_count: Optional[PageCount] = field(
        default=None,
        metadata={
            "name": "page-count",
            "type": "Element",
        }
    )
    word_count: Optional[WordCount] = field(
        default=None,
        metadata={
            "name": "word-count",
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass


@dataclass
class ArchiveCopySource:
    doc_type: str = field(
        init=False,
        default="pdf",
        metadata={
            "name": "DocType",
            "type": "Attribute",
            "required": True,
        }
    )
    value: str = field(
        default="",
        metadata={
            "required": True,
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .access_date import (
    Ack,
    Bio,
    DefList,
    FnGroup,
    Glossary,
    ListType,
    Notes,
)
from .article_meta import ArticleMeta
from .journal_meta import JournalMeta


@dataclass
class Front:
    """
    <div> <h3>Front Matter</h3> </div>
    """
    class Meta:
        name = "front"

    journal_meta: Optional[JournalMeta] = field(
        default=None,
        metadata={
            "name": "journal-meta",
            "type": "Element",
        }
    )
    article_meta: Optional[ArticleMeta] = field(
        default=None,
        metadata={
            "name": "article-meta",
            "type": "Element",
            "required": True,
        }
    )
    def_list: List[DefList] = field(
        default_factory=list,
        metadata={
            "name": "def-list",
            "type": "Element",
        }
    )
    list_value: List[ListType] = field(
        default_factory=list,
        metadata={
            "name": "list",
            "type": "Element",
        }
    )
    ack: List[Ack] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    bio: List[Bio] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    fn_group: List[FnGroup] = field(
        default_factory=list,
        metadata={
            "name": "fn-group",
            "type": "Element",
        }
    )
    glossary: List[Glossary] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notes: List[Notes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )



from enum import Enum

__NAMESPACE__ = "http://www.w3.org/1998/Math/MathML"


class MaligngroupGroupalign(Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"
    DECIMALPOINT = "decimalpoint"



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .access_date import (
    PublisherLoc,
    PublisherName,
)


@dataclass
class Publisher:
    """
    <div> <h3>Publisher</h3> </div>
    """
    class Meta:
        name = "publisher"

    publisher_name: List[PublisherName] = field(
        default_factory=list,
        metadata={
            "name": "publisher-name",
            "type": "Element",
            "sequence": 1,
        }
    )
    publisher_loc: List[PublisherLoc] = field(
        default_factory=list,
        metadata={
            "name": "publisher-loc",
            "type": "Element",
            "sequence": 1,
        }
    )
    content_type: Optional[str] = field(
        default=None,
        metadata={
            "name": "content-type",
            "type": "Attribute",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional, Union
from .access_date import (
    Bold,
    FixedCase,
    Italic,
    Monospace,
    Overline,
    Roman,
    SansSerif,
    Sc,
    Strike,
    Sub,
    Sup,
    Underline,
)
from .org.w3.pkg_1999.xlink.actuate_value import ActuateValue
from .org.w3.pkg_1999.xlink.show_value import ShowValue
from .org.w3.pkg_1999.xlink.type_value import TypeValue
from .org.w3.xml.pkg_1998.namespace.lang_value import LangValue
from .overline_end import OverlineEnd
from .overline_start import OverlineStart
from .underline_end import UnderlineEnd
from .underline_start import UnderlineStart


@dataclass
class ResourceName:
    """
    <div> <h3>Resource Name</h3> </div>
    """
    class Meta:
        name = "resource-name"

    content_type: Optional[str] = field(
        default=None,
        metadata={
            "name": "content-type",
            "type": "Attribute",
        }
    )
    hreflang: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    specific_use: Optional[str] = field(
        default=None,
        metadata={
            "name": "specific-use",
            "type": "Attribute",
        }
    )
    actuate: Optional[ActuateValue] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    role: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    show: Optional[ShowValue] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    title: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    type: TypeValue = field(
        init=False,
        default=TypeValue.SIMPLE,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )
    lang: Optional[Union[str, LangValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )
    content: List[object] = field(
        default_factory=list,
        metadata={
            "type": "Wildcard",
            "namespace": "##any",
            "mixed": True,
            "choices": (
                {
                    "name": "bold",
                    "type": Bold,
                },
                {
                    "name": "fixed-case",
                    "type": FixedCase,
                },
                {
                    "name": "italic",
                    "type": Italic,
                },
                {
                    "name": "monospace",
                    "type": Monospace,
                },
                {
                    "name": "overline",
                    "type": Overline,
                },
                {
                    "name": "overline-start",
                    "type": OverlineStart,
                },
                {
                    "name": "overline-end",
                    "type": OverlineEnd,
                },
                {
                    "name": "roman",
                    "type": Roman,
                },
                {
                    "name": "sans-serif",
                    "type": SansSerif,
                },
                {
                    "name": "sc",
                    "type": Sc,
                },
                {
                    "name": "strike",
                    "type": Strike,
                },
                {
                    "name": "underline",
                    "type": Underline,
                },
                {
                    "name": "underline-start",
                    "type": UnderlineStart,
                },
                {
                    "name": "underline-end",
                    "type": UnderlineEnd,
                },
                {
                    "name": "sub",
                    "type": Sub,
                },
                {
                    "name": "sup",
                    "type": Sup,
                },
            ),
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional
from .abstract_1 import Abstract1
from .article_date import ArticleDate
from .article_pub_model import ArticlePubModel
from .article_title_1 import ArticleTitle1
from .author_list import AuthorList
from .data_bank_list import DataBankList
from .elocation_id_1 import ElocationId1
from .grant_list import GrantList
from .journal import Journal
from .pagination import Pagination
from .publication_type_list import PublicationTypeList
from .vernacular_title import VernacularTitle


@dataclass
class Article1:
    class Meta:
        name = "Article"

    pub_model: Optional[ArticlePubModel] = field(
        default=None,
        metadata={
            "name": "PubModel",
            "type": "Attribute",
            "required": True,
        }
    )
    journal: Optional[Journal] = field(
        default=None,
        metadata={
            "name": "Journal",
            "type": "Element",
            "required": True,
        }
    )
    article_title: Optional[ArticleTitle1] = field(
        default=None,
        metadata={
            "name": "ArticleTitle",
            "type": "Element",
            "required": True,
        }
    )
    pagination: Optional[Pagination] = field(
        default=None,
        metadata={
            "name": "Pagination",
            "type": "Element",
        }
    )
    elocation_id: List[ElocationId1] = field(
        default_factory=list,
        metadata={
            "name": "ELocationID",
            "type": "Element",
            "max_occurs": 2,
        }
    )
    abstract: Optional[Abstract1] = field(
        default=None,
        metadata={
            "name": "Abstract",
            "type": "Element",
        }
    )
    author_list: Optional[AuthorList] = field(
        default=None,
        metadata={
            "name": "AuthorList",
            "type": "Element",
        }
    )
    language: List[str] = field(
        default_factory=list,
        metadata={
            "name": "Language",
            "type": "Element",
            "min_occurs": 1,
        }
    )
    data_bank_list: Optional[DataBankList] = field(
        default=None,
        metadata={
            "name": "DataBankList",
            "type": "Element",
        }
    )
    grant_list: Optional[GrantList] = field(
        default=None,
        metadata={
            "name": "GrantList",
            "type": "Element",
        }
    )
    publication_type_list: Optional[PublicationTypeList] = field(
        default=None,
        metadata={
            "name": "PublicationTypeList",
            "type": "Element",
            "required": True,
        }
    )
    vernacular_title: Optional[VernacularTitle] = field(
        default=None,
        metadata={
            "name": "VernacularTitle",
            "type": "Element",
        }
    )
    article_date: List[ArticleDate] = field(
        default_factory=list,
        metadata={
            "name": "ArticleDate",
            "type": "Element",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional, Union
from .access_date import (
    AwardId,
    FundingSource,
)
from .award_desc import AwardDesc
from .award_name import AwardName
from .org.w3.pkg_1999.xlink.actuate_value import ActuateValue
from .org.w3.pkg_1999.xlink.show_value import ShowValue
from .org.w3.pkg_1999.xlink.type_value import TypeValue
from .org.w3.xml.pkg_1998.namespace.lang_value import LangValue
from .principal_award_recipient import PrincipalAwardRecipient
from .principal_investigator import PrincipalInvestigator
from .support_source import SupportSource


@dataclass
class AwardGroup:
    """
    <div> <h3>Award Group</h3> </div>
    """
    class Meta:
        name = "award-group"

    funding_source: List[FundingSource] = field(
        default_factory=list,
        metadata={
            "name": "funding-source",
            "type": "Element",
        }
    )
    support_source: List[SupportSource] = field(
        default_factory=list,
        metadata={
            "name": "support-source",
            "type": "Element",
        }
    )
    award_id: List[AwardId] = field(
        default_factory=list,
        metadata={
            "name": "award-id",
            "type": "Element",
        }
    )
    award_name: Optional[AwardName] = field(
        default=None,
        metadata={
            "name": "award-name",
            "type": "Element",
        }
    )
    award_desc: Optional[AwardDesc] = field(
        default=None,
        metadata={
            "name": "award-desc",
            "type": "Element",
        }
    )
    principal_award_recipient: List[PrincipalAwardRecipient] = field(
        default_factory=list,
        metadata={
            "name": "principal-award-recipient",
            "type": "Element",
        }
    )
    principal_investigator: List[PrincipalInvestigator] = field(
        default_factory=list,
        metadata={
            "name": "principal-investigator",
            "type": "Element",
        }
    )
    award_type: Optional[str] = field(
        default=None,
        metadata={
            "name": "award-type",
            "type": "Attribute",
        }
    )
    hreflang: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    rid: List[str] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "tokens": True,
        }
    )
    specific_use: Optional[str] = field(
        default=None,
        metadata={
            "name": "specific-use",
            "type": "Attribute",
        }
    )
    actuate: Optional[ActuateValue] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    role: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    show: Optional[ShowValue] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    title: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    type: TypeValue = field(
        init=False,
        default=TypeValue.SIMPLE,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )
    lang: Optional[Union[str, LangValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional
from xsdata.models.datatype import XmlDate

__NAMESPACE__ = "http://www.niso.org/schemas/ali/1.0/"


@dataclass
class FreeToRead:
    class Meta:
        name = "free_to_read"
        namespace = "http://www.niso.org/schemas/ali/1.0/"

    end_date: Optional[XmlDate] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    start_date: Optional[XmlDate] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "required": True,
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional
from .type_value import TypeValue

__NAMESPACE__ = "http://www.w3.org/1999/xlink"


@dataclass
class LocatorType:
    """
    :ivar type:
    :ivar href:
    :ivar role:
    :ivar title:
    :ivar label: label is not required, but locators have no particular
        XLink function if they are not labeled.
    """
    class Meta:
        name = "locatorType"

    type: TypeValue = field(
        init=False,
        default=TypeValue.LOCATOR,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
            "required": True,
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
            "required": True,
        }
    )
    role: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    title: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
    label: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/1999/xlink",
        }
    )
